<?php
/**
 * Shopware 5
 * Copyright (c) shopware AG
 *
 * According to our dual licensing model, this program can be used either
 * under the terms of the GNU Affero General Public License, version 3,
 * or under a proprietary license.
 *
 * The texts of the GNU Affero General Public License with an additional
 * permission and of our proprietary license can be found at and
 * in the LICENSE file you have received along with this program.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * "Shopware" is a registered trademark of shopware AG.
 * The licensing of the program under the AGPLv3 does not imply a
 * trademark license. Therefore any rights, title and interest in
 * our trademarks remain entirely with us.
 */

/**
 * @group disable
 * @category  Shopware
 * @package   Shopware\Tests
 * @copyright Copyright (c) 2012, shopware AG (http://www.shopware.de)
 */
class Shopware_Tests_Models_Category_DetailQueryTest extends Enlight_Components_Test_TestCase
{
    /**
     * @var \Shopware\Models\Category\Repository
     */
    protected $repo = null;

    protected $expected = array(
        1 => array(
            0 => array(
                'id' => 1,
                'parentId' => null,
                'name' => 'Root',
                'position' => 0,
                                'metaKeywords' => null,
                'metaDescription' => null,
                'cmsHeadline' => null,
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => false,
                'external' => null,
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => null,
                'articles' => array(),
                'attribute' => null,
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        3 => array(
            0 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 10,
                        'name' => 'Aperitif-Glas Demi Sec',
                        'mainDetail' => array('id' => 16, 'number' => 'SW10010',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    1 => array(
                        'id' => 3,
                        'name' => 'Münsterländer Aperitif 16%',
                        'mainDetail' => array('id' => 3, 'number' => 'SW10003',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    2 => array(
                        'id' => 4,
                        'name' => 'Latte Macchiato 17%',
                        'mainDetail' => array('id' => 4, 'number' => 'SW10004',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    3 => array(
                        'id' => 6,
                        'name' => 'Cigar Special 40%',
                        'mainDetail' => array('id' => 6, 'number' => 'SW10006',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    4 => array(
                        'id' => 9,
                        'name' => 'Special Finish Lagerkorn X.O. 32%',
                        'mainDetail' => array('id' => 15, 'number' => 'SW10009',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    5 => array(
                        'id' => 8,
                        'name' => 'T.S. Privat 41,5 %',
                        'mainDetail' => array('id' => 14, 'number' => 'SW10008',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    6 => array(
                        'id' => 11,
                        'name' => 'Münsterländer Aperitif Präsent Box',
                        'mainDetail' => array('id' => 17, 'number' => 'SW10011',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    7 => array(
                        'id' => 5,
                        'name' => 'Emmelkamp Holunder Likör 18%',
                        'mainDetail' => array('id' => 252, 'number' => 'SW10005.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    8 => array(
                        'id' => 2,
                        'name' => 'Münsterländer Lagerkorn 32%',
                        'mainDetail' => array('id' => 125, 'number' => 'SW10002.3',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    9 => array(
                        'id' => 7,
                        'name' => 'Wacholder Premium extra mild 32%',
                        'mainDetail' => array('id' => 249, 'number' => 'SW10007.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    10 => array(
                        'id' => 12,
                        'name' => 'Kobra Vodka 37,5%',
                        'mainDetail' => array('id' => 18, 'number' => 'SW10012',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    11 => array(
                        'id' => 98,
                        'name' => 'Fliegenklatsche grün',
                        'mainDetail' => array('id' => 163, 'number' => 'SW10101',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    12 => array(
                        'id' => 100,
                        'name' => 'Fliegenklatsche lila',
                        'mainDetail' => array('id' => 165, 'number' => 'SW10102',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    13 => array(
                        'id' => 101,
                        'name' => 'Fliegenklatsche gelb',
                        'mainDetail' => array('id' => 166, 'number' => 'SW10100',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    14 => array(
                        'id' => 102,
                        'name' => 'iPadtasche mit Stiftmappe',
                        'mainDetail' => array('id' => 167, 'number' => 'SW10103',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    15 => array(
                        'id' => 104,
                        'name' => 'Reisekoffer klein',
                        'mainDetail' => array('id' => 169, 'number' => 'SW10105',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    16 => array(
                        'id' => 103,
                        'name' => 'Reisekoffer groß',
                        'mainDetail' => array('id' => 168, 'number' => 'SW10104',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    17 => array(
                        'id' => 105,
                        'name' => 'Kosmetiktasche',
                        'mainDetail' => array('id' => 170, 'number' => 'SW10107',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    18 => array(
                        'id' => 106,
                        'name' => 'Kosmetiktasche',
                        'mainDetail' => array('id' => 171, 'number' => 'SW10108',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    19 => array(
                        'id' => 107,
                        'name' => 'Kosmetiktasche',
                        'mainDetail' => array('id' => 172, 'number' => 'SW10106',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    20 => array(
                        'id' => 96,
                        'name' => 'Strandbag',
                        'mainDetail' => array('id' => 161, 'number' => 'SW10098',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    21 => array(
                        'id' => 108,
                        'name' => 'Strandbag',
                        'mainDetail' => array('id' => 173, 'number' => 'SW10109',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    22 => array(
                        'id' => 109,
                        'name' => 'Strandbag Fantasy',
                        'mainDetail' => array('id' => 174, 'number' => 'SW10110',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    23 => array(
                        'id' => 110,
                        'name' => 'Tasche Feed Me',
                        'mainDetail' => array('id' => 175, 'number' => 'SW10113',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    24 => array(
                        'id' => 112,
                        'name' => 'Tasche Remember Me',
                        'mainDetail' => array('id' => 177, 'number' => 'SW10112',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    25 => array(
                        'id' => 162,
                        'name' => 'Sommer-Sandale Pink',
                        'mainDetail' => array('id' => 380, 'number' => 'SW10162.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    26 => array(
                        'id' => 161,
                        'name' => 'Sommer-Sandale Leder Rot-Braun',
                        'mainDetail' => array('id' => 372, 'number' => 'SW10161.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    27 => array(
                        'id' => 159,
                        'name' => 'Strohhut Women mit UV Schutz',
                        'mainDetail' => array('id' => 362, 'number' => 'SW10159',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    28 => array(
                        'id' => 158,
                        'name' => 'Strohhut mit UV Schutz',
                        'mainDetail' => array('id' => 361, 'number' => 'SW10158',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    29 => array(
                        'id' => 157,
                        'name' => 'Panama Hut mit UV Schutz',
                        'mainDetail' => array('id' => 360, 'number' => 'SW10157',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    30 => array(
                        'id' => 156,
                        'name' => 'Flip Flops Deep Red',
                        'mainDetail' => array('id' => 346, 'number' => 'SW10156.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    31 => array(
                        'id' => 154,
                        'name' => 'Bikini Rainbow',
                        'mainDetail' => array('id' => 343, 'number' => 'SW10154',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    32 => array(
                        'id' => 153,
                        'name' => 'Flip Flops, in mehreren Farben verfügbar',
                        'mainDetail' => array('id' => 322, 'number' => 'SW10153.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    33 => array(
                        'id' => 152,
                        'name' => 'Bikini Sunshine Yellow',
                        'mainDetail' => array('id' => 299, 'number' => 'SW10152',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    34 => array(
                        'id' => 151,
                        'name' => 'Bikini Stripes',
                        'mainDetail' => array('id' => 298, 'number' => 'SW10151',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    35 => array(
                        'id' => 150,
                        'name' => 'Bikini Ocean Blue',
                        'mainDetail' => array('id' => 297, 'number' => 'SW10150',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    36 => array(
                        'id' => 160,
                        'name' => 'Sommer Sandale Ocean Blue',
                        'mainDetail' => array('id' => 364, 'number' => 'SW10160.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    37 => array(
                        'id' => 163,
                        'name' => 'Sommerschal Flower Power',
                        'mainDetail' => array('id' => 387, 'number' => 'SW10163',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    38 => array(
                        'id' => 164,
                        'name' => 'Sommerschal Fresh Green',
                        'mainDetail' => array('id' => 388, 'number' => 'SW10164',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    39 => array(
                        'id' => 165,
                        'name' => 'Sommerschal Light Red aus Seide',
                        'mainDetail' => array('id' => 389, 'number' => 'SW10165',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    40 => array(
                        'id' => 166,
                        'name' => 'Sonnenbrille Big Eyes',
                        'mainDetail' => array('id' => 390, 'number' => 'SW10166',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    41 => array(
                        'id' => 167,
                        'name' => 'Sonnenbrille Speed Eyes',
                        'mainDetail' => array('id' => 391, 'number' => 'SW10167',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    42 => array(
                        'id' => 168,
                        'name' => 'Pilotenbrille Sunset Red',
                        'mainDetail' => array('id' => 392, 'number' => 'SW10168',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    43 => array(
                        'id' => 169,
                        'name' => 'Pilotenbrille Silver Sky',
                        'mainDetail' => array('id' => 393, 'number' => 'SW10169',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    44 => array(
                        'id' => 171,
                        'name' => 'Sonnencreme ab  LSF 10',
                        'mainDetail' => array('id' => 396, 'number' => 'SW10171.1',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    45 => array(
                        'id' => 172,
                        'name' => 'Sonnencreme Sunblocker LSF 50',
                        'mainDetail' => array('id' => 401, 'number' => 'SW10172',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    46 => array(
                        'id' => 174,
                        'name' => 'Strandkleid Short Red',
                        'mainDetail' => array('id' => 403, 'number' => 'SW10174',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    47 => array(
                        'id' => 173,
                        'name' => 'Strandkleid Flower Power',
                        'mainDetail' => array('id' => 402, 'number' => 'SW10173',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    48 => array(
                        'id' => 176,
                        'name' => 'Strandtuch Gras-Green',
                        'mainDetail' => array('id' => 405, 'number' => 'SW10176',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    49 => array(
                        'id' => 175,
                        'name' => 'Strandtuch Sunny',
                        'mainDetail' => array('id' => 404, 'number' => 'SW10175',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    50 => array(
                        'id' => 177,
                        'name' => 'Strandtuch Stripes für Kinder',
                        'mainDetail' => array('id' => 406, 'number' => 'SW10177',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    51 => array(
                        'id' => 179,
                        'name' => 'Strandtuch in mehreren Farben',
                        'mainDetail' => array('id' => 409, 'number' => 'SW10179.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    52 => array(
                        'id' => 181,
                        'name' => 'Reisekoffer Set',
                        'mainDetail' => array('id' => 421, 'number' => 'SW10181',),
                        'supplier' => array('id' => 5, 'name' => 'Access Oires Sisters',),
                    ),
                    53 => array(
                        'id' => 180,
                        'name' => 'Reisekoffer, in mehreren Farben',
                        'mainDetail' => array('id' => 417, 'number' => 'SW10180.1',),
                        'supplier' => array('id' => 5, 'name' => 'Access Oires Sisters',),
                    ),
                    54 => array(
                        'id' => 129,
                        'name' => 'Sonnenschirm Fortino, 270cm',
                        'mainDetail' => array('id' => 261, 'number' => 'SW10129',),
                        'supplier' => array('id' => 11, 'name' => 'Sonnenschirm Versand',),
                    ),
                    55 => array(
                        'id' => 132,
                        'name' => 'Sonnenschirm Sunwing C+, 260cm',
                        'mainDetail' => array('id' => 264, 'number' => 'SW10132',),
                        'supplier' => array('id' => 11, 'name' => 'Sonnenschirm Versand',),
                    ),
                    56 => array(
                        'id' => 128,
                        'name' => 'Sonnenschirm Alu-Style, 270cm',
                        'mainDetail' => array('id' => 260, 'number' => 'SW10128',),
                        'supplier' => array('id' => 11, 'name' => 'Sonnenschirm Versand',),
                    ),
                    57 => array(
                        'id' => 130,
                        'name' => 'Sonnenschirm Pendalex V+, 280cm',
                        'mainDetail' => array('id' => 262, 'number' => 'SW10130',),
                        'supplier' => array('id' => 11, 'name' => 'Sonnenschirm Versand',),
                    ),
                    58 => array(
                        'id' => 131,
                        'name' => 'Sonnenschirm Sombrano, 350cm',
                        'mainDetail' => array('id' => 263, 'number' => 'SW10131',),
                        'supplier' => array('id' => 11, 'name' => 'Sonnenschirm Versand',),
                    ),
                    59 => array(
                        'id' => 170,
                        'name' => 'Sonnenbrille "Red"',
                        'mainDetail' => array('id' => 394, 'number' => 'SW10170',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    60 => array(
                        'id' => 97,
                        'name' => 'Eisförmchen',
                        'mainDetail' => array('id' => 162, 'number' => 'SW10099',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    61 => array(
                        'id' => 178,
                        'name' => 'Strandtuch "Ibiza"',
                        'mainDetail' => array('id' => 407, 'number' => 'SW10178',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    62 => array(
                        'id' => 63,
                        'name' => 'Beistelltisch',
                        'mainDetail' => array('id' => 126, 'number' => 'SW10062',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    63 => array(
                        'id' => 66,
                        'name' => 'Garderobe',
                        'mainDetail' => array('id' => 129, 'number' => 'SW10065',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    64 => array(
                        'id' => 67,
                        'name' => 'antike Kommode',
                        'mainDetail' => array('id' => 130, 'number' => 'SW10066',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    65 => array(
                        'id' => 68,
                        'name' => 'Kommode Shabby Chic',
                        'mainDetail' => array('id' => 131, 'number' => 'SW10067',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    66 => array(
                        'id' => 69,
                        'name' => 'Wandregal',
                        'mainDetail' => array('id' => 132, 'number' => 'SW10070',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    67 => array(
                        'id' => 70,
                        'name' => 'Regal groß',
                        'mainDetail' => array('id' => 133, 'number' => 'SW10071',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    68 => array(
                        'id' => 71,
                        'name' => 'Schlüsselkasten',
                        'mainDetail' => array('id' => 134, 'number' => 'SW10072',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    69 => array(
                        'id' => 72,
                        'name' => 'Schmuckkästchen',
                        'mainDetail' => array('id' => 135, 'number' => 'SW10073',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    70 => array(
                        'id' => 73,
                        'name' => 'Spiegelregal',
                        'mainDetail' => array('id' => 136, 'number' => 'SW10074',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    71 => array(
                        'id' => 74,
                        'name' => 'Stuhl',
                        'mainDetail' => array('id' => 137, 'number' => 'SW10075',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    72 => array(
                        'id' => 75,
                        'name' => 'Esstisch',
                        'mainDetail' => array('id' => 138, 'number' => 'SW10076',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    73 => array(
                        'id' => 76,
                        'name' => 'Couchtisch rund braun',
                        'mainDetail' => array('id' => 139, 'number' => 'SW10077',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    74 => array(
                        'id' => 77,
                        'name' => 'Couchtisch eckig weiß',
                        'mainDetail' => array('id' => 140, 'number' => 'SW10078',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    75 => array(
                        'id' => 79,
                        'name' => 'Spiegel rund',
                        'mainDetail' => array('id' => 142, 'number' => 'SW10080',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    76 => array(
                        'id' => 80,
                        'name' => 'Backform gelb',
                        'mainDetail' => array('id' => 143, 'number' => 'SW10081',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    77 => array(
                        'id' => 82,
                        'name' => 'Pralinen-Backform',
                        'mainDetail' => array('id' => 145, 'number' => 'SW10083',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    78 => array(
                        'id' => 83,
                        'name' => 'Back-Set 3 teilig',
                        'mainDetail' => array('id' => 146, 'number' => 'SW10084',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    79 => array(
                        'id' => 84,
                        'name' => 'Löffel-Set',
                        'mainDetail' => array('id' => 147, 'number' => 'SW10085',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    80 => array(
                        'id' => 85,
                        'name' => 'Schneebesen',
                        'mainDetail' => array('id' => 148, 'number' => 'SW10086',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    81 => array(
                        'id' => 87,
                        'name' => 'Schüssel Style Blumen',
                        'mainDetail' => array('id' => 150, 'number' => 'SW10088',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    82 => array(
                        'id' => 86,
                        'name' => 'Schüssel Style Vögel',
                        'mainDetail' => array('id' => 149, 'number' => 'SW10087',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    83 => array(
                        'id' => 88,
                        'name' => 'Schüssel Style Ringe rot und weiß',
                        'mainDetail' => array('id' => 151, 'number' => 'SW10089',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    84 => array(
                        'id' => 89,
                        'name' => 'Teigschaber',
                        'mainDetail' => array('id' => 153, 'number' => 'SW10090.1',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    85 => array(
                        'id' => 90,
                        'name' => 'Teller Style Hühner',
                        'mainDetail' => array('id' => 155, 'number' => 'SW10091',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    86 => array(
                        'id' => 91,
                        'name' => 'Teller Style Vögel und Blumen',
                        'mainDetail' => array('id' => 156, 'number' => 'SW10092',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    87 => array(
                        'id' => 92,
                        'name' => 'Teller Style Rot und Pink',
                        'mainDetail' => array('id' => 157, 'number' => 'SW10093',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    88 => array(
                        'id' => 93,
                        'name' => 'Blumenarrangement mit Keramiktopf',
                        'mainDetail' => array('id' => 158, 'number' => 'SW10095',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    89 => array(
                        'id' => 94,
                        'name' => 'Blütenarrangement mit Rattan',
                        'mainDetail' => array('id' => 159, 'number' => 'SW10096',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    90 => array(
                        'id' => 95,
                        'name' => 'Blütenarrangement mit Rattan',
                        'mainDetail' => array('id' => 160, 'number' => 'SW10097',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    91 => array(
                        'id' => 78,
                        'name' => 'Uhr antik',
                        'mainDetail' => array('id' => 141, 'number' => 'SW10079',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    92 => array(
                        'id' => 64,
                        'name' => 'Briefkasten',
                        'mainDetail' => array('id' => 127, 'number' => 'SW10063',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    93 => array(
                        'id' => 81,
                        'name' => 'Backform pink',
                        'mainDetail' => array('id' => 144, 'number' => 'SW10082',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    94 => array(
                        'id' => 248,
                        'name' => 'Versandkosten nach Gewicht',
                        'mainDetail' => array('id' => 803, 'number' => 'SW100755036993',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    95 => array(
                        'id' => 65,
                        'name' => 'Fensterspiegel',
                        'mainDetail' => array('id' => 128, 'number' => 'SW10064',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    96 => array(
                        'id' => 13,
                        'name' => 'Pai Mu Tan Tee weiss',
                        'mainDetail' => array('id' => 19, 'number' => 'SW10013',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    97 => array(
                        'id' => 122,
                        'name' => 'Sasse Korn 32%',
                        'mainDetail' => array('id' => 256, 'number' => 'SW10123.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    98 => array(
                        'id' => 37,
                        'name' => 'Esslack',
                        'mainDetail' => array('id' => 43, 'number' => 'SW10036',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    99 => array(
                        'id' => 39,
                        'name' => 'Mehrzwecknudeln',
                        'mainDetail' => array('id' => 45, 'number' => 'SW10038',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    100 => array(
                        'id' => 41,
                        'name' => 'Traubenbatterie',
                        'mainDetail' => array('id' => 47, 'number' => 'SW10040',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    101 => array(
                        'id' => 42,
                        'name' => 'Tubenhonig',
                        'mainDetail' => array('id' => 48, 'number' => 'SW10041',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    102 => array(
                        'id' => 38,
                        'name' => 'Kraftstoff',
                        'mainDetail' => array('id' => 44, 'number' => 'SW10037',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    103 => array(
                        'id' => 40,
                        'name' => 'Schokoleim',
                        'mainDetail' => array('id' => 46, 'number' => 'SW10039',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    104 => array(
                        'id' => 43,
                        'name' => 'Ölwechsel',
                        'mainDetail' => array('id' => 49, 'number' => 'SW10042',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    105 => array(
                        'id' => 272,
                        'name' => 'Spachtelmasse',
                        'mainDetail' => array('id' => 827, 'number' => 'SW10239',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    106 => array(
                        'id' => 44,
                        'name' => 'Bienenkleber',
                        'mainDetail' => array('id' => 50, 'number' => 'SW10043',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    107 => array(
                        'id' => 238,
                        'name' => 'Strandbag Sailor',
                        'mainDetail' => array('id' => 793, 'number' => 'SW10229',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    108 => array(
                        'id' => 213,
                        'name' => 'Surfbrett',
                        'mainDetail' => array('id' => 751, 'number' => 'SW10211',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    109 => array(
                        'id' => 155,
                        'name' => 'Flip Flop Sunshine Yellow',
                        'mainDetail' => array('id' => 353, 'number' => 'SW10155.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    110 => array(
                        'id' => 214,
                        'name' => 'All Natural - Rosemary Grapefruit Conditioner',
                        'mainDetail' => array('id' => 753, 'number' => 'SW10212.1',),
                        'supplier' => array('id' => 15, 'name' => 'stop the water while using me',),
                    ),
                    111 => array(
                        'id' => 216,
                        'name' => 'All Natural - Sesame Sage Bodylotion',
                        'mainDetail' => array('id' => 761, 'number' => 'SW10214.1',),
                        'supplier' => array('id' => 15, 'name' => 'stop the water while using me',),
                    ),
                    112 => array(
                        'id' => 217,
                        'name' => 'All Natural - Orange Wild Herbs Shower Gel',
                        'mainDetail' => array('id' => 766, 'number' => 'SW10215.1',),
                        'supplier' => array('id' => 15, 'name' => 'stop the water while using me',),
                    ),
                    113 => array(
                        'id' => 215,
                        'name' => 'All Natural - Rosemary Grapefruit Shampoo',
                        'mainDetail' => array('id' => 757, 'number' => 'SW10213.1',),
                        'supplier' => array('id' => 15, 'name' => 'stop the water while using me',),
                    ),
                    114 => array(
                        'id' => 218,
                        'name' => 'All Natural - Lemon Honey Soap',
                        'mainDetail' => array('id' => 769, 'number' => 'SW10216.1',),
                        'supplier' => array('id' => 15, 'name' => 'stop the water while using me',),
                    ),
                    115 => array(
                        'id' => 148,
                        'name' => 'Reisetasche Gladstone Wildleder',
                        'mainDetail' => array('id' => 295, 'number' => 'SW10148',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    116 => array(
                        'id' => 222,
                        'name' => 'Dekokissen Blume',
                        'mainDetail' => array('id' => 775, 'number' => 'SW10217',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    117 => array(
                        'id' => 224,
                        'name' => 'Dekokissen Bus',
                        'mainDetail' => array('id' => 777, 'number' => 'SW10218',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    118 => array(
                        'id' => 231,
                        'name' => 'Notizbuch New York',
                        'mainDetail' => array('id' => 786, 'number' => 'SW10223',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    119 => array(
                        'id' => 233,
                        'name' => 'Notizbuch London',
                        'mainDetail' => array('id' => 788, 'number' => 'SW10224',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    120 => array(
                        'id' => 234,
                        'name' => 'Notizbuch Paris',
                        'mainDetail' => array('id' => 789, 'number' => 'SW10225',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    121 => array(
                        'id' => 226,
                        'name' => 'Magnete ABC',
                        'mainDetail' => array('id' => 779, 'number' => 'SW10220',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    122 => array(
                        'id' => 237,
                        'name' => 'Stoffherz kariert',
                        'mainDetail' => array('id' => 792, 'number' => 'SW10228',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    123 => array(
                        'id' => 236,
                        'name' => 'Servietten',
                        'mainDetail' => array('id' => 791, 'number' => 'SW10227',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    124 => array(
                        'id' => 235,
                        'name' => 'Deko Topf',
                        'mainDetail' => array('id' => 790, 'number' => 'SW10226',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    125 => array(
                        'id' => 229,
                        'name' => 'Magnete London',
                        'mainDetail' => array('id' => 784, 'number' => 'SW10222',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    126 => array(
                        'id' => 225,
                        'name' => 'Dekokissen Vogel',
                        'mainDetail' => array('id' => 778, 'number' => 'SW10219',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    127 => array(
                        'id' => 117,
                        'name' => 'Kicker Figuren Set, große Auswahl',
                        'mainDetail' => array('id' => 220, 'number' => 'SW10118.1',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    128 => array(
                        'id' => 118,
                        'name' => 'Kicker Torzähler',
                        'mainDetail' => array('id' => 236, 'number' => 'SW10119',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    129 => array(
                        'id' => 120,
                        'name' => 'Kickerball Kork',
                        'mainDetail' => array('id' => 238, 'number' => 'SW10121',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    130 => array(
                        'id' => 119,
                        'name' => 'Kickerball Standard',
                        'mainDetail' => array('id' => 237, 'number' => 'SW10120',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    131 => array(
                        'id' => 121,
                        'name' => 'Kickerball Probierset',
                        'mainDetail' => array('id' => 239, 'number' => 'SW10122',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    132 => array(
                        'id' => 113,
                        'name' => 'Kicker Champ Elite',
                        'mainDetail' => array('id' => 178, 'number' => 'SW10114',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    133 => array(
                        'id' => 114,
                        'name' => 'Kicker Champ Elite Pro (in vielen Farben)',
                        'mainDetail' => array('id' => 182, 'number' => 'SW10115.3',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    134 => array(
                        'id' => 115,
                        'name' => 'Kicker Champ Family platzsparend',
                        'mainDetail' => array('id' => 185, 'number' => 'SW10116',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    135 => array(
                        'id' => 116,
                        'name' => 'Kicker Champ, individuell gestaltbar',
                        'mainDetail' => array('id' => 186, 'number' => 'SW10117',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    136 => array(
                        'id' => 123,
                        'name' => 'Kicker XXL Champ Elite Pro',
                        'mainDetail' => array('id' => 241, 'number' => 'SW10111',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    137 => array(
                        'id' => 195,
                        'name' => 'Kicker Service Box',
                        'mainDetail' => array('id' => 435, 'number' => 'SW10194',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    138 => array(
                        'id' => 241,
                        'name' => 'Dartpfeil Steel Atomic',
                        'mainDetail' => array('id' => 796, 'number' => 'SW10232',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    139 => array(
                        'id' => 245,
                        'name' => 'Bumerang',
                        'mainDetail' => array('id' => 800, 'number' => 'SW10236',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    140 => array(
                        'id' => 246,
                        'name' => 'Dart-Set',
                        'mainDetail' => array('id' => 801, 'number' => 'SW10237',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    141 => array(
                        'id' => 242,
                        'name' => 'Dartpfeil Steel Smiley 745',
                        'mainDetail' => array('id' => 797, 'number' => 'SW10233',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    142 => array(
                        'id' => 240,
                        'name' => 'Dartscheibe Circle',
                        'mainDetail' => array('id' => 795, 'number' => 'SW10231',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    143 => array(
                        'id' => 239,
                        'name' => 'Dart Automat Standgerät',
                        'mainDetail' => array('id' => 794, 'number' => 'SW10230',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    144 => array(
                        'id' => 142,
                        'name' => 'Herrenhandschuh,halbfinger aus Peccary Leder',
                        'mainDetail' => array('id' => 289, 'number' => 'SW10142',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    145 => array(
                        'id' => 144,
                        'name' => 'Navigator Lederhaube schwarz',
                        'mainDetail' => array('id' => 291, 'number' => 'SW10144',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    146 => array(
                        'id' => 145,
                        'name' => 'Mütze Vintage Driver',
                        'mainDetail' => array('id' => 292, 'number' => 'SW10145',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    147 => array(
                        'id' => 143,
                        'name' => 'Navigator Lederhaube braun',
                        'mainDetail' => array('id' => 290, 'number' => 'SW10143',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    148 => array(
                        'id' => 134,
                        'name' => 'Balmoral Flatcap Tweed',
                        'mainDetail' => array('id' => 278, 'number' => 'SW10134',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    149 => array(
                        'id' => 135,
                        'name' => 'Damenhandschuh, halbfinger aus Peccary Leder',
                        'mainDetail' => array('id' => 279, 'number' => 'SW10135',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    150 => array(
                        'id' => 136,
                        'name' => 'Damenhandschuh aus Peccary Leder zweifarbig',
                        'mainDetail' => array('id' => 280, 'number' => 'SW10136',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    151 => array(
                        'id' => 137,
                        'name' => 'Fahrerbrille Chronos',
                        'mainDetail' => array('id' => 281, 'number' => 'SW10137',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    152 => array(
                        'id' => 141,
                        'name' => 'Fahrerhandschuh aus Peccary Leder',
                        'mainDetail' => array('id' => 288, 'number' => 'SW10141',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    153 => array(
                        'id' => 196,
                        'name' => 'Artikel mit ähnlichen Produkten',
                        'mainDetail' => array('id' => 436, 'number' => 'SW10195',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    154 => array(
                        'id' => 194,
                        'name' => 'Artikel mit Zubehör',
                        'mainDetail' => array('id' => 434, 'number' => 'SW10193',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    155 => array(
                        'id' => 243,
                        'name' => 'Artikel mit Emailbenachrichtigung',
                        'mainDetail' => array('id' => 798, 'number' => 'SW10234',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    156 => array(
                        'id' => 201,
                        'name' => 'Hervorgehobene Darstellung',
                        'mainDetail' => array('id' => 441, 'number' => 'SW10200',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    157 => array(
                        'id' => 200,
                        'name' => 'Artikelkennzeichnung NEU',
                        'mainDetail' => array('id' => 440, 'number' => 'SW10199',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    158 => array(
                        'id' => 199,
                        'name' => 'Artikel mit Abverkauf',
                        'mainDetail' => array('id' => 439, 'number' => 'SW10198',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    159 => array(
                        'id' => 198,
                        'name' => 'Artikel mit Bewertung',
                        'mainDetail' => array('id' => 438, 'number' => 'SW10197',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    160 => array(
                        'id' => 197,
                        'name' => 'ESD Download Artikel',
                        'mainDetail' => array('id' => 437, 'number' => 'SW10196',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    161 => array(
                        'id' => 205,
                        'name' => 'Artikel mit Aufpreiskonfigurator',
                        'mainDetail' => array('id' => 726, 'number' => 'SW10204.1',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    162 => array(
                        'id' => 204,
                        'name' => 'Artikel mit Tabellenkonfigurator',
                        'mainDetail' => array('id' => 689, 'number' => 'SW10203.1',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    163 => array(
                        'id' => 203,
                        'name' => 'Artikel mit Auswahlkonfigurator',
                        'mainDetail' => array('id' => 549, 'number' => 'SW10202.1',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    164 => array(
                        'id' => 202,
                        'name' => 'Artikel mit Standardkonfigurator',
                        'mainDetail' => array('id' => 444, 'number' => 'SW10201.2',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    165 => array(
                        'id' => 206,
                        'name' => 'Artikel mit Grundpreisberechnung',
                        'mainDetail' => array('id' => 744, 'number' => 'SW10205.3',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    166 => array(
                        'id' => 209,
                        'name' => 'Staffelpreise',
                        'mainDetail' => array('id' => 747, 'number' => 'SW10208',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    167 => array(
                        'id' => 208,
                        'name' => 'Pseudopreis',
                        'mainDetail' => array('id' => 746, 'number' => 'SW10207',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    168 => array(
                        'id' => 207,
                        'name' => 'Staffelung, Mindest- / Maximalabnahme',
                        'mainDetail' => array('id' => 745, 'number' => 'SW10206',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    169 => array(
                        'id' => 221,
                        'name' => 'Versandkosten Optionen',
                        'mainDetail' => array('id' => 774, 'number' => 'SW1000299',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    170 => array(
                        'id' => 223,
                        'name' => 'Ausweichversandkosten',
                        'mainDetail' => array('id' => 780, 'number' => 'SW100718.1',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    171 => array(
                        'id' => 220,
                        'name' => 'Versandkostenfreier Artikel',
                        'mainDetail' => array('id' => 773, 'number' => 'SW10001',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    172 => array(
                        'id' => 219,
                        'name' => 'Express Versand',
                        'mainDetail' => array('id' => 772, 'number' => 'SW10185',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    173 => array(
                        'id' => 230,
                        'name' => 'Abschlag bei Zahlungsarten',
                        'mainDetail' => array('id' => 785, 'number' => 'SW10002694',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    174 => array(
                        'id' => 228,
                        'name' => 'Zahlungsarten & Riskmanagement',
                        'mainDetail' => array('id' => 783, 'number' => 'SW100025211',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    175 => array(
                        'id' => 227,
                        'name' => 'Aufschlag bei Zahlungsarten',
                        'mainDetail' => array('id' => 782, 'number' => 'SW10002841',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    176 => array(
                        'id' => 210,
                        'name' => 'Prämienartikel ab 50 Euro Warenkorb Wert',
                        'mainDetail' => array('id' => 748, 'number' => 'SW10209',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    177 => array(
                        'id' => 247,
                        'name' => 'Prämienartikel ab 100 Euro Warenkorbwert',
                        'mainDetail' => array('id' => 802, 'number' => 'SW10238',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    178 => array(
                        'id' => 211,
                        'name' => 'Prämienartikel ab 250 Euro Warenkorb Wert',
                        'mainDetail' => array('id' => 749, 'number' => 'SW10221',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    179 => array(
                        'id' => 244,
                        'name' => 'Kundengruppen Brutto / Nettopreise',
                        'mainDetail' => array('id' => 799, 'number' => 'SW10235',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    180 => array(
                        'id' => 21,
                        'name' => 'Jasmine Lotus Tee',
                        'mainDetail' => array('id' => 27, 'number' => 'SW10020',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    181 => array(
                        'id' => 19,
                        'name' => 'Oriental Jasmine Tee',
                        'mainDetail' => array('id' => 25, 'number' => 'SW10018',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    182 => array(
                        'id' => 20,
                        'name' => 'Jasmine Phoenix Tee',
                        'mainDetail' => array('id' => 26, 'number' => 'SW10019',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    183 => array(
                        'id' => 18,
                        'name' => 'Pi Lo Chun grüner Tee',
                        'mainDetail' => array('id' => 24, 'number' => 'SW10017',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    184 => array(
                        'id' => 17,
                        'name' => 'Mao Feng grüner Tee',
                        'mainDetail' => array('id' => 23, 'number' => 'SW10016',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    185 => array(
                        'id' => 15,
                        'name' => 'LUNG CHING grüner Tee',
                        'mainDetail' => array('id' => 21, 'number' => 'SW10015',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    186 => array(
                        'id' => 14,
                        'name' => 'Silver Yin Zhen Tee weiss',
                        'mainDetail' => array('id' => 20, 'number' => 'SW10014',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    187 => array(
                        'id' => 31,
                        'name' => 'Grüner Tee Geschenkset',
                        'mainDetail' => array('id' => 37, 'number' => 'SW10030',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    188 => array(
                        'id' => 32,
                        'name' => 'Jasmine Tee Geschenk Set',
                        'mainDetail' => array('id' => 38, 'number' => 'SW10031',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    189 => array(
                        'id' => 33,
                        'name' => 'Oolong Tee Geschenkset',
                        'mainDetail' => array('id' => 39, 'number' => 'SW10032',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    190 => array(
                        'id' => 34,
                        'name' => 'Pu Erh Tee Geschenkset',
                        'mainDetail' => array('id' => 40, 'number' => 'SW10033',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    191 => array(
                        'id' => 35,
                        'name' => 'Schwarzer Tee Geschenkset',
                        'mainDetail' => array('id' => 41, 'number' => 'SW10034',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    192 => array(
                        'id' => 36,
                        'name' => 'Weißer Tee Geschenkset',
                        'mainDetail' => array('id' => 42, 'number' => 'SW10035',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    193 => array(
                        'id' => 29,
                        'name' => 'Porzellan Teeservice',
                        'mainDetail' => array('id' => 35, 'number' => 'SW10028',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    194 => array(
                        'id' => 22,
                        'name' => 'Glas -Teetasse 0,25l',
                        'mainDetail' => array('id' => 28, 'number' => 'SW10021',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    195 => array(
                        'id' => 27,
                        'name' => 'Facil Teezubereiter',
                        'mainDetail' => array('id' => 33, 'number' => 'SW10026',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    196 => array(
                        'id' => 26,
                        'name' => 'Glas Teezubereiter',
                        'mainDetail' => array('id' => 32, 'number' => 'SW10025',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    197 => array(
                        'id' => 23,
                        'name' => 'Glasbecher',
                        'mainDetail' => array('id' => 29, 'number' => 'SW10022',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    198 => array(
                        'id' => 24,
                        'name' => 'Glas-Teekännchen',
                        'mainDetail' => array('id' => 30, 'number' => 'SW10023',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    199 => array(
                        'id' => 25,
                        'name' => 'Glas-Teekanne',
                        'mainDetail' => array('id' => 31, 'number' => 'SW10024',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    200 => array(
                        'id' => 28,
                        'name' => 'Deluxe Eisteezubereiter',
                        'mainDetail' => array('id' => 34, 'number' => 'SW10027',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    201 => array(
                        'id' => 30,
                        'name' => 'Porzellan Tee-Set in Geschenkbox',
                        'mainDetail' => array('id' => 36, 'number' => 'SW10029',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                ),
                'attribute' => array(
                    'id' => 1,
                    'categoryId' => 3,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(
                    0 => array(
                        'id' => 1,
                        'active' => 1,
                        'name' => 'Meine Startseite',
                        'cols' => 4,
                        'rows' => 20,
                        'userId' => 55,
                        'cellHeight' => 185,
                        'articleHeight' => 2,
                        'containerWidth' => 1008,
                        'validFrom' => null,
                        'isLandingPage' => 0,
                        'landingPageBlock' => '',
                        'landingPageTeaser' => '',
                        'seoTitle' => '',
                        'seoKeywords' => '',
                        'seoDescription' => '',
                        'validTo' => null,
                        'template' => 'Standard',
                        'showListing' => false,
                    ),
                ),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        39 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 122,
                        'name' => 'Sasse Korn 32%',
                        'mainDetail' => array('id' => 256, 'number' => 'SW10123.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    1 => array(
                        'id' => 11,
                        'name' => 'Münsterländer Aperitif Präsent Box',
                        'mainDetail' => array('id' => 17, 'number' => 'SW10011',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    2 => array(
                        'id' => 10,
                        'name' => 'Aperitif-Glas Demi Sec',
                        'mainDetail' => array('id' => 16, 'number' => 'SW10010',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    3 => array(
                        'id' => 9,
                        'name' => 'Special Finish Lagerkorn X.O. 32%',
                        'mainDetail' => array('id' => 15, 'number' => 'SW10009',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    4 => array(
                        'id' => 8,
                        'name' => 'T.S. Privat 41,5 %',
                        'mainDetail' => array('id' => 14, 'number' => 'SW10008',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    5 => array(
                        'id' => 6,
                        'name' => 'Cigar Special 40%',
                        'mainDetail' => array('id' => 6, 'number' => 'SW10006',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    6 => array(
                        'id' => 4,
                        'name' => 'Latte Macchiato 17%',
                        'mainDetail' => array('id' => 4, 'number' => 'SW10004',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    7 => array(
                        'id' => 3,
                        'name' => 'Münsterländer Aperitif 16%',
                        'mainDetail' => array('id' => 3, 'number' => 'SW10003',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    8 => array(
                        'id' => 5,
                        'name' => 'Emmelkamp Holunder Likör 18%',
                        'mainDetail' => array('id' => 252, 'number' => 'SW10005.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    9 => array(
                        'id' => 2,
                        'name' => 'Münsterländer Lagerkorn 32%',
                        'mainDetail' => array('id' => 125, 'number' => 'SW10002.3',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    10 => array(
                        'id' => 7,
                        'name' => 'Wacholder Premium extra mild 32%',
                        'mainDetail' => array('id' => 249, 'number' => 'SW10007.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    11 => array(
                        'id' => 12,
                        'name' => 'Kobra Vodka 37,5%',
                        'mainDetail' => array('id' => 18, 'number' => 'SW10012',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    12 => array(
                        'id' => 43,
                        'name' => 'Ölwechsel',
                        'mainDetail' => array('id' => 49, 'number' => 'SW10042',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    13 => array(
                        'id' => 41,
                        'name' => 'Traubenbatterie',
                        'mainDetail' => array('id' => 47, 'number' => 'SW10040',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    14 => array(
                        'id' => 40,
                        'name' => 'Schokoleim',
                        'mainDetail' => array('id' => 46, 'number' => 'SW10039',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    15 => array(
                        'id' => 39,
                        'name' => 'Mehrzwecknudeln',
                        'mainDetail' => array('id' => 45, 'number' => 'SW10038',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    16 => array(
                        'id' => 44,
                        'name' => 'Bienenkleber',
                        'mainDetail' => array('id' => 50, 'number' => 'SW10043',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    17 => array(
                        'id' => 144,
                        'name' => 'Navigator Lederhaube schwarz',
                        'mainDetail' => array('id' => 291, 'number' => 'SW10144',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    18 => array(
                        'id' => 142,
                        'name' => 'Herrenhandschuh,halbfinger aus Peccary Leder',
                        'mainDetail' => array('id' => 289, 'number' => 'SW10142',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    19 => array(
                        'id' => 145,
                        'name' => 'Mütze Vintage Driver',
                        'mainDetail' => array('id' => 292, 'number' => 'SW10145',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    20 => array(
                        'id' => 143,
                        'name' => 'Navigator Lederhaube braun',
                        'mainDetail' => array('id' => 290, 'number' => 'SW10143',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    21 => array(
                        'id' => 148,
                        'name' => 'Reisetasche Gladstone Wildleder',
                        'mainDetail' => array('id' => 295, 'number' => 'SW10148',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    22 => array(
                        'id' => 241,
                        'name' => 'Dartpfeil Steel Atomic',
                        'mainDetail' => array('id' => 796, 'number' => 'SW10232',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    23 => array(
                        'id' => 118,
                        'name' => 'Kicker Torzähler',
                        'mainDetail' => array('id' => 236, 'number' => 'SW10119',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    24 => array(
                        'id' => 116,
                        'name' => 'Kicker Champ, individuell gestaltbar',
                        'mainDetail' => array('id' => 186, 'number' => 'SW10117',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    25 => array(
                        'id' => 242,
                        'name' => 'Dartpfeil Steel Smiley 745',
                        'mainDetail' => array('id' => 797, 'number' => 'SW10233',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    26 => array(
                        'id' => 240,
                        'name' => 'Dartscheibe Circle',
                        'mainDetail' => array('id' => 795, 'number' => 'SW10231',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    27 => array(
                        'id' => 239,
                        'name' => 'Dart Automat Standgerät',
                        'mainDetail' => array('id' => 794, 'number' => 'SW10230',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    28 => array(
                        'id' => 77,
                        'name' => 'Couchtisch eckig weiß',
                        'mainDetail' => array('id' => 140, 'number' => 'SW10078',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    29 => array(
                        'id' => 74,
                        'name' => 'Stuhl',
                        'mainDetail' => array('id' => 137, 'number' => 'SW10075',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    30 => array(
                        'id' => 69,
                        'name' => 'Wandregal',
                        'mainDetail' => array('id' => 132, 'number' => 'SW10070',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    31 => array(
                        'id' => 64,
                        'name' => 'Briefkasten',
                        'mainDetail' => array('id' => 127, 'number' => 'SW10063',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    32 => array(
                        'id' => 67,
                        'name' => 'antike Kommode',
                        'mainDetail' => array('id' => 130, 'number' => 'SW10066',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    33 => array(
                        'id' => 248,
                        'name' => 'Versandkosten nach Gewicht',
                        'mainDetail' => array('id' => 803, 'number' => 'SW100755036993',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    34 => array(
                        'id' => 101,
                        'name' => 'Fliegenklatsche gelb',
                        'mainDetail' => array('id' => 166, 'number' => 'SW10100',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    35 => array(
                        'id' => 90,
                        'name' => 'Teller Style Hühner',
                        'mainDetail' => array('id' => 155, 'number' => 'SW10091',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    36 => array(
                        'id' => 83,
                        'name' => 'Back-Set 3 teilig',
                        'mainDetail' => array('id' => 146, 'number' => 'SW10084',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    37 => array(
                        'id' => 81,
                        'name' => 'Backform pink',
                        'mainDetail' => array('id' => 144, 'number' => 'SW10082',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    38 => array(
                        'id' => 78,
                        'name' => 'Uhr antik',
                        'mainDetail' => array('id' => 141, 'number' => 'SW10079',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    39 => array(
                        'id' => 237,
                        'name' => 'Stoffherz kariert',
                        'mainDetail' => array('id' => 792, 'number' => 'SW10228',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    40 => array(
                        'id' => 236,
                        'name' => 'Servietten',
                        'mainDetail' => array('id' => 791, 'number' => 'SW10227',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    41 => array(
                        'id' => 235,
                        'name' => 'Deko Topf',
                        'mainDetail' => array('id' => 790, 'number' => 'SW10226',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    42 => array(
                        'id' => 229,
                        'name' => 'Magnete London',
                        'mainDetail' => array('id' => 784, 'number' => 'SW10222',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    43 => array(
                        'id' => 225,
                        'name' => 'Dekokissen Vogel',
                        'mainDetail' => array('id' => 778, 'number' => 'SW10219',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    44 => array(
                        'id' => 153,
                        'name' => 'Flip Flops, in mehreren Farben verfügbar',
                        'mainDetail' => array('id' => 322, 'number' => 'SW10153.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    45 => array(
                        'id' => 177,
                        'name' => 'Strandtuch Stripes für Kinder',
                        'mainDetail' => array('id' => 406, 'number' => 'SW10177',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    46 => array(
                        'id' => 160,
                        'name' => 'Sommer Sandale Ocean Blue',
                        'mainDetail' => array('id' => 364, 'number' => 'SW10160.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    47 => array(
                        'id' => 238,
                        'name' => 'Strandbag Sailor',
                        'mainDetail' => array('id' => 793, 'number' => 'SW10229',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    48 => array(
                        'id' => 213,
                        'name' => 'Surfbrett',
                        'mainDetail' => array('id' => 751, 'number' => 'SW10211',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    49 => array(
                        'id' => 178,
                        'name' => 'Strandtuch "Ibiza"',
                        'mainDetail' => array('id' => 407, 'number' => 'SW10178',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    50 => array(
                        'id' => 131,
                        'name' => 'Sonnenschirm Sombrano, 350cm',
                        'mainDetail' => array('id' => 263, 'number' => 'SW10131',),
                        'supplier' => array('id' => 11, 'name' => 'Sonnenschirm Versand',),
                    ),
                    51 => array(
                        'id' => 129,
                        'name' => 'Sonnenschirm Fortino, 270cm',
                        'mainDetail' => array('id' => 261, 'number' => 'SW10129',),
                        'supplier' => array('id' => 11, 'name' => 'Sonnenschirm Versand',),
                    ),
                    52 => array(
                        'id' => 172,
                        'name' => 'Sonnencreme Sunblocker LSF 50',
                        'mainDetail' => array('id' => 401, 'number' => 'SW10172',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    53 => array(
                        'id' => 218,
                        'name' => 'All Natural - Lemon Honey Soap',
                        'mainDetail' => array('id' => 769, 'number' => 'SW10216.1',),
                        'supplier' => array('id' => 15, 'name' => 'stop the water while using me',),
                    ),
                    54 => array(
                        'id' => 181,
                        'name' => 'Reisekoffer Set',
                        'mainDetail' => array('id' => 421, 'number' => 'SW10181',),
                        'supplier' => array('id' => 5, 'name' => 'Access Oires Sisters',),
                    ),
                    55 => array(
                        'id' => 110,
                        'name' => 'Tasche Feed Me',
                        'mainDetail' => array('id' => 175, 'number' => 'SW10113',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    56 => array(
                        'id' => 104,
                        'name' => 'Reisekoffer klein',
                        'mainDetail' => array('id' => 169, 'number' => 'SW10105',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    57 => array(
                        'id' => 102,
                        'name' => 'iPadtasche mit Stiftmappe',
                        'mainDetail' => array('id' => 167, 'number' => 'SW10103',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    58 => array(
                        'id' => 170,
                        'name' => 'Sonnenbrille "Red"',
                        'mainDetail' => array('id' => 394, 'number' => 'SW10170',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    59 => array(
                        'id' => 166,
                        'name' => 'Sonnenbrille Big Eyes',
                        'mainDetail' => array('id' => 390, 'number' => 'SW10166',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    60 => array(
                        'id' => 159,
                        'name' => 'Strohhut Women mit UV Schutz',
                        'mainDetail' => array('id' => 362, 'number' => 'SW10159',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    61 => array(
                        'id' => 157,
                        'name' => 'Panama Hut mit UV Schutz',
                        'mainDetail' => array('id' => 360, 'number' => 'SW10157',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    62 => array(
                        'id' => 35,
                        'name' => 'Schwarzer Tee Geschenkset',
                        'mainDetail' => array('id' => 41, 'number' => 'SW10034',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    63 => array(
                        'id' => 34,
                        'name' => 'Pu Erh Tee Geschenkset',
                        'mainDetail' => array('id' => 40, 'number' => 'SW10033',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    64 => array(
                        'id' => 33,
                        'name' => 'Oolong Tee Geschenkset',
                        'mainDetail' => array('id' => 39, 'number' => 'SW10032',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    65 => array(
                        'id' => 32,
                        'name' => 'Jasmine Tee Geschenk Set',
                        'mainDetail' => array('id' => 38, 'number' => 'SW10031',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    66 => array(
                        'id' => 31,
                        'name' => 'Grüner Tee Geschenkset',
                        'mainDetail' => array('id' => 37, 'number' => 'SW10030',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    67 => array(
                        'id' => 21,
                        'name' => 'Jasmine Lotus Tee',
                        'mainDetail' => array('id' => 27, 'number' => 'SW10020',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    68 => array(
                        'id' => 20,
                        'name' => 'Jasmine Phoenix Tee',
                        'mainDetail' => array('id' => 26, 'number' => 'SW10019',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    69 => array(
                        'id' => 18,
                        'name' => 'Pi Lo Chun grüner Tee',
                        'mainDetail' => array('id' => 24, 'number' => 'SW10017',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    70 => array(
                        'id' => 19,
                        'name' => 'Oriental Jasmine Tee',
                        'mainDetail' => array('id' => 25, 'number' => 'SW10018',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    71 => array(
                        'id' => 17,
                        'name' => 'Mao Feng grüner Tee',
                        'mainDetail' => array('id' => 23, 'number' => 'SW10016',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    72 => array(
                        'id' => 15,
                        'name' => 'LUNG CHING grüner Tee',
                        'mainDetail' => array('id' => 21, 'number' => 'SW10015',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    73 => array(
                        'id' => 14,
                        'name' => 'Silver Yin Zhen Tee weiss',
                        'mainDetail' => array('id' => 20, 'number' => 'SW10014',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    74 => array(
                        'id' => 13,
                        'name' => 'Pai Mu Tan Tee weiss',
                        'mainDetail' => array('id' => 19, 'number' => 'SW10013',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    75 => array(
                        'id' => 36,
                        'name' => 'Weißer Tee Geschenkset',
                        'mainDetail' => array('id' => 42, 'number' => 'SW10035',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    76 => array(
                        'id' => 22,
                        'name' => 'Glas -Teetasse 0,25l',
                        'mainDetail' => array('id' => 28, 'number' => 'SW10021',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    77 => array(
                        'id' => 23,
                        'name' => 'Glasbecher',
                        'mainDetail' => array('id' => 29, 'number' => 'SW10022',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    78 => array(
                        'id' => 24,
                        'name' => 'Glas-Teekännchen',
                        'mainDetail' => array('id' => 30, 'number' => 'SW10023',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    79 => array(
                        'id' => 25,
                        'name' => 'Glas-Teekanne',
                        'mainDetail' => array('id' => 31, 'number' => 'SW10024',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    80 => array(
                        'id' => 26,
                        'name' => 'Glas Teezubereiter',
                        'mainDetail' => array('id' => 32, 'number' => 'SW10025',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    81 => array(
                        'id' => 210,
                        'name' => 'Prämienartikel ab 50 Euro Warenkorb Wert',
                        'mainDetail' => array('id' => 748, 'number' => 'SW10209',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    82 => array(
                        'id' => 247,
                        'name' => 'Prämienartikel ab 100 Euro Warenkorbwert',
                        'mainDetail' => array('id' => 802, 'number' => 'SW10238',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    83 => array(
                        'id' => 211,
                        'name' => 'Prämienartikel ab 250 Euro Warenkorb Wert',
                        'mainDetail' => array('id' => 749, 'number' => 'SW10221',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    84 => array(
                        'id' => 205,
                        'name' => 'Artikel mit Aufpreiskonfigurator',
                        'mainDetail' => array('id' => 726, 'number' => 'SW10204.1',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    85 => array(
                        'id' => 204,
                        'name' => 'Artikel mit Tabellenkonfigurator',
                        'mainDetail' => array('id' => 689, 'number' => 'SW10203.1',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    86 => array(
                        'id' => 203,
                        'name' => 'Artikel mit Auswahlkonfigurator',
                        'mainDetail' => array('id' => 549, 'number' => 'SW10202.1',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    87 => array(
                        'id' => 202,
                        'name' => 'Artikel mit Standardkonfigurator',
                        'mainDetail' => array('id' => 444, 'number' => 'SW10201.2',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    88 => array(
                        'id' => 243,
                        'name' => 'Artikel mit Emailbenachrichtigung',
                        'mainDetail' => array('id' => 798, 'number' => 'SW10234',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    89 => array(
                        'id' => 201,
                        'name' => 'Hervorgehobene Darstellung',
                        'mainDetail' => array('id' => 441, 'number' => 'SW10200',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    90 => array(
                        'id' => 200,
                        'name' => 'Artikelkennzeichnung NEU',
                        'mainDetail' => array('id' => 440, 'number' => 'SW10199',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    91 => array(
                        'id' => 199,
                        'name' => 'Artikel mit Abverkauf',
                        'mainDetail' => array('id' => 439, 'number' => 'SW10198',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    92 => array(
                        'id' => 198,
                        'name' => 'Artikel mit Bewertung',
                        'mainDetail' => array('id' => 438, 'number' => 'SW10197',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    93 => array(
                        'id' => 197,
                        'name' => 'ESD Download Artikel',
                        'mainDetail' => array('id' => 437, 'number' => 'SW10196',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    94 => array(
                        'id' => 194,
                        'name' => 'Artikel mit Zubehör',
                        'mainDetail' => array('id' => 434, 'number' => 'SW10193',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    95 => array(
                        'id' => 196,
                        'name' => 'Artikel mit ähnlichen Produkten',
                        'mainDetail' => array('id' => 436, 'number' => 'SW10195',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    96 => array(
                        'id' => 230,
                        'name' => 'Abschlag bei Zahlungsarten',
                        'mainDetail' => array('id' => 785, 'number' => 'SW10002694',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    97 => array(
                        'id' => 228,
                        'name' => 'Zahlungsarten & Riskmanagement',
                        'mainDetail' => array('id' => 783, 'number' => 'SW100025211',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    98 => array(
                        'id' => 227,
                        'name' => 'Aufschlag bei Zahlungsarten',
                        'mainDetail' => array('id' => 782, 'number' => 'SW10002841',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    99 => array(
                        'id' => 221,
                        'name' => 'Versandkosten Optionen',
                        'mainDetail' => array('id' => 774, 'number' => 'SW1000299',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    100 => array(
                        'id' => 223,
                        'name' => 'Ausweichversandkosten',
                        'mainDetail' => array('id' => 780, 'number' => 'SW100718.1',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    101 => array(
                        'id' => 220,
                        'name' => 'Versandkostenfreier Artikel',
                        'mainDetail' => array('id' => 773, 'number' => 'SW10001',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    102 => array(
                        'id' => 219,
                        'name' => 'Express Versand',
                        'mainDetail' => array('id' => 772, 'number' => 'SW10185',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    103 => array(
                        'id' => 209,
                        'name' => 'Staffelpreise',
                        'mainDetail' => array('id' => 747, 'number' => 'SW10208',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    104 => array(
                        'id' => 206,
                        'name' => 'Artikel mit Grundpreisberechnung',
                        'mainDetail' => array('id' => 744, 'number' => 'SW10205.3',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    105 => array(
                        'id' => 208,
                        'name' => 'Pseudopreis',
                        'mainDetail' => array('id' => 746, 'number' => 'SW10207',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    106 => array(
                        'id' => 207,
                        'name' => 'Staffelung, Mindest- / Maximalabnahme',
                        'mainDetail' => array('id' => 745, 'number' => 'SW10206',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                ),
                'attribute' => array(
                    'id' => 43,
                    'categoryId' => 39,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(
                    0 => array(
                        'id' => 10,
                        'active' => 1,
                        'name' => 'English',
                        'cols' => 4,
                        'rows' => 20,
                        'userId' => 53,
                        'cellHeight' => 185,
                        'articleHeight' => 2,
                        'containerWidth' => 1008,
                        'validFrom' => null,
                        'isLandingPage' => 0,
                        'landingPageBlock' => '',
                        'landingPageTeaser' => '',
                        'seoTitle' => '',
                        'seoKeywords' => '',
                        'seoDescription' => '',
                        'validTo' => null,
                        'template' => 'Standard',
                        'showListing' => false,
                    ),
                ),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        5 => array(
            0 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 10,
                        'name' => 'Aperitif-Glas Demi Sec',
                        'mainDetail' => array('id' => 16, 'number' => 'SW10010',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    1 => array(
                        'id' => 3,
                        'name' => 'Münsterländer Aperitif 16%',
                        'mainDetail' => array('id' => 3, 'number' => 'SW10003',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    2 => array(
                        'id' => 4,
                        'name' => 'Latte Macchiato 17%',
                        'mainDetail' => array('id' => 4, 'number' => 'SW10004',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    3 => array(
                        'id' => 6,
                        'name' => 'Cigar Special 40%',
                        'mainDetail' => array('id' => 6, 'number' => 'SW10006',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    4 => array(
                        'id' => 9,
                        'name' => 'Special Finish Lagerkorn X.O. 32%',
                        'mainDetail' => array('id' => 15, 'number' => 'SW10009',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    5 => array(
                        'id' => 8,
                        'name' => 'T.S. Privat 41,5 %',
                        'mainDetail' => array('id' => 14, 'number' => 'SW10008',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    6 => array(
                        'id' => 11,
                        'name' => 'Münsterländer Aperitif Präsent Box',
                        'mainDetail' => array('id' => 17, 'number' => 'SW10011',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    7 => array(
                        'id' => 5,
                        'name' => 'Emmelkamp Holunder Likör 18%',
                        'mainDetail' => array('id' => 252, 'number' => 'SW10005.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    8 => array(
                        'id' => 2,
                        'name' => 'Münsterländer Lagerkorn 32%',
                        'mainDetail' => array('id' => 125, 'number' => 'SW10002.3',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    9 => array(
                        'id' => 7,
                        'name' => 'Wacholder Premium extra mild 32%',
                        'mainDetail' => array('id' => 249, 'number' => 'SW10007.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    10 => array(
                        'id' => 12,
                        'name' => 'Kobra Vodka 37,5%',
                        'mainDetail' => array('id' => 18, 'number' => 'SW10012',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    11 => array(
                        'id' => 13,
                        'name' => 'Pai Mu Tan Tee weiss',
                        'mainDetail' => array('id' => 19, 'number' => 'SW10013',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    12 => array(
                        'id' => 122,
                        'name' => 'Sasse Korn 32%',
                        'mainDetail' => array('id' => 256, 'number' => 'SW10123.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    13 => array(
                        'id' => 37,
                        'name' => 'Esslack',
                        'mainDetail' => array('id' => 43, 'number' => 'SW10036',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    14 => array(
                        'id' => 39,
                        'name' => 'Mehrzwecknudeln',
                        'mainDetail' => array('id' => 45, 'number' => 'SW10038',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    15 => array(
                        'id' => 41,
                        'name' => 'Traubenbatterie',
                        'mainDetail' => array('id' => 47, 'number' => 'SW10040',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    16 => array(
                        'id' => 42,
                        'name' => 'Tubenhonig',
                        'mainDetail' => array('id' => 48, 'number' => 'SW10041',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    17 => array(
                        'id' => 38,
                        'name' => 'Kraftstoff',
                        'mainDetail' => array('id' => 44, 'number' => 'SW10037',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    18 => array(
                        'id' => 40,
                        'name' => 'Schokoleim',
                        'mainDetail' => array('id' => 46, 'number' => 'SW10039',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    19 => array(
                        'id' => 43,
                        'name' => 'Ölwechsel',
                        'mainDetail' => array('id' => 49, 'number' => 'SW10042',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    20 => array(
                        'id' => 272,
                        'name' => 'Spachtelmasse',
                        'mainDetail' => array('id' => 827, 'number' => 'SW10239',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    21 => array(
                        'id' => 44,
                        'name' => 'Bienenkleber',
                        'mainDetail' => array('id' => 50, 'number' => 'SW10043',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    22 => array(
                        'id' => 21,
                        'name' => 'Jasmine Lotus Tee',
                        'mainDetail' => array('id' => 27, 'number' => 'SW10020',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    23 => array(
                        'id' => 19,
                        'name' => 'Oriental Jasmine Tee',
                        'mainDetail' => array('id' => 25, 'number' => 'SW10018',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    24 => array(
                        'id' => 20,
                        'name' => 'Jasmine Phoenix Tee',
                        'mainDetail' => array('id' => 26, 'number' => 'SW10019',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    25 => array(
                        'id' => 18,
                        'name' => 'Pi Lo Chun grüner Tee',
                        'mainDetail' => array('id' => 24, 'number' => 'SW10017',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    26 => array(
                        'id' => 17,
                        'name' => 'Mao Feng grüner Tee',
                        'mainDetail' => array('id' => 23, 'number' => 'SW10016',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    27 => array(
                        'id' => 15,
                        'name' => 'LUNG CHING grüner Tee',
                        'mainDetail' => array('id' => 21, 'number' => 'SW10015',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    28 => array(
                        'id' => 14,
                        'name' => 'Silver Yin Zhen Tee weiss',
                        'mainDetail' => array('id' => 20, 'number' => 'SW10014',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    29 => array(
                        'id' => 31,
                        'name' => 'Grüner Tee Geschenkset',
                        'mainDetail' => array('id' => 37, 'number' => 'SW10030',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    30 => array(
                        'id' => 32,
                        'name' => 'Jasmine Tee Geschenk Set',
                        'mainDetail' => array('id' => 38, 'number' => 'SW10031',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    31 => array(
                        'id' => 33,
                        'name' => 'Oolong Tee Geschenkset',
                        'mainDetail' => array('id' => 39, 'number' => 'SW10032',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    32 => array(
                        'id' => 34,
                        'name' => 'Pu Erh Tee Geschenkset',
                        'mainDetail' => array('id' => 40, 'number' => 'SW10033',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    33 => array(
                        'id' => 35,
                        'name' => 'Schwarzer Tee Geschenkset',
                        'mainDetail' => array('id' => 41, 'number' => 'SW10034',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    34 => array(
                        'id' => 36,
                        'name' => 'Weißer Tee Geschenkset',
                        'mainDetail' => array('id' => 42, 'number' => 'SW10035',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    35 => array(
                        'id' => 29,
                        'name' => 'Porzellan Teeservice',
                        'mainDetail' => array('id' => 35, 'number' => 'SW10028',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    36 => array(
                        'id' => 22,
                        'name' => 'Glas -Teetasse 0,25l',
                        'mainDetail' => array('id' => 28, 'number' => 'SW10021',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    37 => array(
                        'id' => 27,
                        'name' => 'Facil Teezubereiter',
                        'mainDetail' => array('id' => 33, 'number' => 'SW10026',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    38 => array(
                        'id' => 26,
                        'name' => 'Glas Teezubereiter',
                        'mainDetail' => array('id' => 32, 'number' => 'SW10025',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    39 => array(
                        'id' => 23,
                        'name' => 'Glasbecher',
                        'mainDetail' => array('id' => 29, 'number' => 'SW10022',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    40 => array(
                        'id' => 24,
                        'name' => 'Glas-Teekännchen',
                        'mainDetail' => array('id' => 30, 'number' => 'SW10023',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    41 => array(
                        'id' => 25,
                        'name' => 'Glas-Teekanne',
                        'mainDetail' => array('id' => 31, 'number' => 'SW10024',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    42 => array(
                        'id' => 28,
                        'name' => 'Deluxe Eisteezubereiter',
                        'mainDetail' => array('id' => 34, 'number' => 'SW10027',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    43 => array(
                        'id' => 30,
                        'name' => 'Porzellan Tee-Set in Geschenkbox',
                        'mainDetail' => array('id' => 36, 'number' => 'SW10029',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                ),
                'attribute' => array(
                    'id' => 3,
                    'categoryId' => 5,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(
                    0 => array(
                        'id' => 2,
                        'active' => 1,
                        'name' => 'Genusswelten',
                        'cols' => 3,
                        'rows' => 20,
                        'userId' => 57,
                        'cellHeight' => 185,
                        'articleHeight' => 2,
                        'containerWidth' => 808,
                        'validFrom' => null,
                        'isLandingPage' => 0,
                        'landingPageBlock' => '',
                        'landingPageTeaser' => '',
                        'seoTitle' => '',
                        'seoKeywords' => '',
                        'seoDescription' => '',
                        'validTo' => null,
                        'template' => 'Standard',
                        'showListing' => false,
                    ),
                ),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        6 => array(
            0 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 98,
                        'name' => 'Fliegenklatsche grün',
                        'mainDetail' => array('id' => 163, 'number' => 'SW10101',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    1 => array(
                        'id' => 100,
                        'name' => 'Fliegenklatsche lila',
                        'mainDetail' => array('id' => 165, 'number' => 'SW10102',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    2 => array(
                        'id' => 101,
                        'name' => 'Fliegenklatsche gelb',
                        'mainDetail' => array('id' => 166, 'number' => 'SW10100',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    3 => array(
                        'id' => 102,
                        'name' => 'iPadtasche mit Stiftmappe',
                        'mainDetail' => array('id' => 167, 'number' => 'SW10103',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    4 => array(
                        'id' => 104,
                        'name' => 'Reisekoffer klein',
                        'mainDetail' => array('id' => 169, 'number' => 'SW10105',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    5 => array(
                        'id' => 103,
                        'name' => 'Reisekoffer groß',
                        'mainDetail' => array('id' => 168, 'number' => 'SW10104',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    6 => array(
                        'id' => 105,
                        'name' => 'Kosmetiktasche',
                        'mainDetail' => array('id' => 170, 'number' => 'SW10107',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    7 => array(
                        'id' => 106,
                        'name' => 'Kosmetiktasche',
                        'mainDetail' => array('id' => 171, 'number' => 'SW10108',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    8 => array(
                        'id' => 107,
                        'name' => 'Kosmetiktasche',
                        'mainDetail' => array('id' => 172, 'number' => 'SW10106',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    9 => array(
                        'id' => 96,
                        'name' => 'Strandbag',
                        'mainDetail' => array('id' => 161, 'number' => 'SW10098',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    10 => array(
                        'id' => 108,
                        'name' => 'Strandbag',
                        'mainDetail' => array('id' => 173, 'number' => 'SW10109',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    11 => array(
                        'id' => 109,
                        'name' => 'Strandbag Fantasy',
                        'mainDetail' => array('id' => 174, 'number' => 'SW10110',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    12 => array(
                        'id' => 110,
                        'name' => 'Tasche Feed Me',
                        'mainDetail' => array('id' => 175, 'number' => 'SW10113',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    13 => array(
                        'id' => 112,
                        'name' => 'Tasche Remember Me',
                        'mainDetail' => array('id' => 177, 'number' => 'SW10112',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    14 => array(
                        'id' => 162,
                        'name' => 'Sommer-Sandale Pink',
                        'mainDetail' => array('id' => 380, 'number' => 'SW10162.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    15 => array(
                        'id' => 161,
                        'name' => 'Sommer-Sandale Leder Rot-Braun',
                        'mainDetail' => array('id' => 372, 'number' => 'SW10161.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    16 => array(
                        'id' => 159,
                        'name' => 'Strohhut Women mit UV Schutz',
                        'mainDetail' => array('id' => 362, 'number' => 'SW10159',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    17 => array(
                        'id' => 158,
                        'name' => 'Strohhut mit UV Schutz',
                        'mainDetail' => array('id' => 361, 'number' => 'SW10158',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    18 => array(
                        'id' => 157,
                        'name' => 'Panama Hut mit UV Schutz',
                        'mainDetail' => array('id' => 360, 'number' => 'SW10157',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    19 => array(
                        'id' => 156,
                        'name' => 'Flip Flops Deep Red',
                        'mainDetail' => array('id' => 346, 'number' => 'SW10156.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    20 => array(
                        'id' => 154,
                        'name' => 'Bikini Rainbow',
                        'mainDetail' => array('id' => 343, 'number' => 'SW10154',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    21 => array(
                        'id' => 153,
                        'name' => 'Flip Flops, in mehreren Farben verfügbar',
                        'mainDetail' => array('id' => 322, 'number' => 'SW10153.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    22 => array(
                        'id' => 152,
                        'name' => 'Bikini Sunshine Yellow',
                        'mainDetail' => array('id' => 299, 'number' => 'SW10152',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    23 => array(
                        'id' => 151,
                        'name' => 'Bikini Stripes',
                        'mainDetail' => array('id' => 298, 'number' => 'SW10151',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    24 => array(
                        'id' => 150,
                        'name' => 'Bikini Ocean Blue',
                        'mainDetail' => array('id' => 297, 'number' => 'SW10150',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    25 => array(
                        'id' => 160,
                        'name' => 'Sommer Sandale Ocean Blue',
                        'mainDetail' => array('id' => 364, 'number' => 'SW10160.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    26 => array(
                        'id' => 163,
                        'name' => 'Sommerschal Flower Power',
                        'mainDetail' => array('id' => 387, 'number' => 'SW10163',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    27 => array(
                        'id' => 164,
                        'name' => 'Sommerschal Fresh Green',
                        'mainDetail' => array('id' => 388, 'number' => 'SW10164',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    28 => array(
                        'id' => 165,
                        'name' => 'Sommerschal Light Red aus Seide',
                        'mainDetail' => array('id' => 389, 'number' => 'SW10165',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    29 => array(
                        'id' => 166,
                        'name' => 'Sonnenbrille Big Eyes',
                        'mainDetail' => array('id' => 390, 'number' => 'SW10166',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    30 => array(
                        'id' => 167,
                        'name' => 'Sonnenbrille Speed Eyes',
                        'mainDetail' => array('id' => 391, 'number' => 'SW10167',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    31 => array(
                        'id' => 168,
                        'name' => 'Pilotenbrille Sunset Red',
                        'mainDetail' => array('id' => 392, 'number' => 'SW10168',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    32 => array(
                        'id' => 169,
                        'name' => 'Pilotenbrille Silver Sky',
                        'mainDetail' => array('id' => 393, 'number' => 'SW10169',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    33 => array(
                        'id' => 171,
                        'name' => 'Sonnencreme ab  LSF 10',
                        'mainDetail' => array('id' => 396, 'number' => 'SW10171.1',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    34 => array(
                        'id' => 172,
                        'name' => 'Sonnencreme Sunblocker LSF 50',
                        'mainDetail' => array('id' => 401, 'number' => 'SW10172',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    35 => array(
                        'id' => 174,
                        'name' => 'Strandkleid Short Red',
                        'mainDetail' => array('id' => 403, 'number' => 'SW10174',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    36 => array(
                        'id' => 173,
                        'name' => 'Strandkleid Flower Power',
                        'mainDetail' => array('id' => 402, 'number' => 'SW10173',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    37 => array(
                        'id' => 176,
                        'name' => 'Strandtuch Gras-Green',
                        'mainDetail' => array('id' => 405, 'number' => 'SW10176',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    38 => array(
                        'id' => 175,
                        'name' => 'Strandtuch Sunny',
                        'mainDetail' => array('id' => 404, 'number' => 'SW10175',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    39 => array(
                        'id' => 177,
                        'name' => 'Strandtuch Stripes für Kinder',
                        'mainDetail' => array('id' => 406, 'number' => 'SW10177',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    40 => array(
                        'id' => 179,
                        'name' => 'Strandtuch in mehreren Farben',
                        'mainDetail' => array('id' => 409, 'number' => 'SW10179.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    41 => array(
                        'id' => 181,
                        'name' => 'Reisekoffer Set',
                        'mainDetail' => array('id' => 421, 'number' => 'SW10181',),
                        'supplier' => array('id' => 5, 'name' => 'Access Oires Sisters',),
                    ),
                    42 => array(
                        'id' => 180,
                        'name' => 'Reisekoffer, in mehreren Farben',
                        'mainDetail' => array('id' => 417, 'number' => 'SW10180.1',),
                        'supplier' => array('id' => 5, 'name' => 'Access Oires Sisters',),
                    ),
                    43 => array(
                        'id' => 129,
                        'name' => 'Sonnenschirm Fortino, 270cm',
                        'mainDetail' => array('id' => 261, 'number' => 'SW10129',),
                        'supplier' => array('id' => 11, 'name' => 'Sonnenschirm Versand',),
                    ),
                    44 => array(
                        'id' => 132,
                        'name' => 'Sonnenschirm Sunwing C+, 260cm',
                        'mainDetail' => array('id' => 264, 'number' => 'SW10132',),
                        'supplier' => array('id' => 11, 'name' => 'Sonnenschirm Versand',),
                    ),
                    45 => array(
                        'id' => 128,
                        'name' => 'Sonnenschirm Alu-Style, 270cm',
                        'mainDetail' => array('id' => 260, 'number' => 'SW10128',),
                        'supplier' => array('id' => 11, 'name' => 'Sonnenschirm Versand',),
                    ),
                    46 => array(
                        'id' => 130,
                        'name' => 'Sonnenschirm Pendalex V+, 280cm',
                        'mainDetail' => array('id' => 262, 'number' => 'SW10130',),
                        'supplier' => array('id' => 11, 'name' => 'Sonnenschirm Versand',),
                    ),
                    47 => array(
                        'id' => 131,
                        'name' => 'Sonnenschirm Sombrano, 350cm',
                        'mainDetail' => array('id' => 263, 'number' => 'SW10131',),
                        'supplier' => array('id' => 11, 'name' => 'Sonnenschirm Versand',),
                    ),
                    48 => array(
                        'id' => 170,
                        'name' => 'Sonnenbrille "Red"',
                        'mainDetail' => array('id' => 394, 'number' => 'SW10170',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    49 => array(
                        'id' => 97,
                        'name' => 'Eisförmchen',
                        'mainDetail' => array('id' => 162, 'number' => 'SW10099',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    50 => array(
                        'id' => 178,
                        'name' => 'Strandtuch "Ibiza"',
                        'mainDetail' => array('id' => 407, 'number' => 'SW10178',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    51 => array(
                        'id' => 238,
                        'name' => 'Strandbag Sailor',
                        'mainDetail' => array('id' => 793, 'number' => 'SW10229',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    52 => array(
                        'id' => 213,
                        'name' => 'Surfbrett',
                        'mainDetail' => array('id' => 751, 'number' => 'SW10211',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    53 => array(
                        'id' => 155,
                        'name' => 'Flip Flop Sunshine Yellow',
                        'mainDetail' => array('id' => 353, 'number' => 'SW10155.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    54 => array(
                        'id' => 214,
                        'name' => 'All Natural - Rosemary Grapefruit Conditioner',
                        'mainDetail' => array('id' => 753, 'number' => 'SW10212.1',),
                        'supplier' => array('id' => 15, 'name' => 'stop the water while using me',),
                    ),
                    55 => array(
                        'id' => 216,
                        'name' => 'All Natural - Sesame Sage Bodylotion',
                        'mainDetail' => array('id' => 761, 'number' => 'SW10214.1',),
                        'supplier' => array('id' => 15, 'name' => 'stop the water while using me',),
                    ),
                    56 => array(
                        'id' => 217,
                        'name' => 'All Natural - Orange Wild Herbs Shower Gel',
                        'mainDetail' => array('id' => 766, 'number' => 'SW10215.1',),
                        'supplier' => array('id' => 15, 'name' => 'stop the water while using me',),
                    ),
                    57 => array(
                        'id' => 215,
                        'name' => 'All Natural - Rosemary Grapefruit Shampoo',
                        'mainDetail' => array('id' => 757, 'number' => 'SW10213.1',),
                        'supplier' => array('id' => 15, 'name' => 'stop the water while using me',),
                    ),
                    58 => array(
                        'id' => 218,
                        'name' => 'All Natural - Lemon Honey Soap',
                        'mainDetail' => array('id' => 769, 'number' => 'SW10216.1',),
                        'supplier' => array('id' => 15, 'name' => 'stop the water while using me',),
                    ),
                    59 => array(
                        'id' => 148,
                        'name' => 'Reisetasche Gladstone Wildleder',
                        'mainDetail' => array('id' => 295, 'number' => 'SW10148',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                ),
                'attribute' => array(
                    'id' => 4,
                    'categoryId' => 6,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(
                    0 => array(
                        'id' => 5,
                        'active' => 1,
                        'name' => 'Stop The Water While Using Me',
                        'cols' => 4,
                        'rows' => 20,
                        'userId' => 60,
                        'cellHeight' => 185,
                        'articleHeight' => 2,
                        'containerWidth' => 1008,
                        'validFrom' => null,
                        'isLandingPage' => 1,
                        'landingPageBlock' => 'leftMiddle',
                        'landingPageTeaser' => 'media/image/testbild.jpg',
                        'seoTitle' => '',
                        'seoKeywords' => '',
                        'seoDescription' => '',
                        'validTo' => null,
                        'template' => 'Standard',
                        'showListing' => false,
                    ),
                    1 => array(
                        'id' => 9,
                        'active' => 1,
                        'name' => 'Passend für Ihren Sommerurlaub',
                        'cols' => 4,
                        'rows' => 20,
                        'userId' => 57,
                        'cellHeight' => 185,
                        'articleHeight' => 2,
                        'containerWidth' => 1008,
                        'validFrom' => null,
                        'isLandingPage' => 1,
                        'landingPageBlock' => 'leftMiddle',
                        'landingPageTeaser' => '',
                        'seoTitle' => '',
                        'seoKeywords' => '',
                        'seoDescription' => '',
                        'validTo' => null,
                        'template' => 'Standard',
                        'showListing' => false,
                    ),
                    2 => array(
                        'id' => 7,
                        'active' => 1,
                        'name' => 'Sommerwelten',
                        'cols' => 4,
                        'rows' => 20,
                        'userId' => 51,
                        'cellHeight' => 185,
                        'articleHeight' => 2,
                        'containerWidth' => 808,
                        'validFrom' => null,
                        'isLandingPage' => 0,
                        'landingPageBlock' => '',
                        'landingPageTeaser' => '',
                        'seoTitle' => '',
                        'seoKeywords' => '',
                        'seoDescription' => '',
                        'validTo' => null,
                        'template' => 'Standard',
                        'showListing' => false,
                    ),
                ),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        8 => array(
            0 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 63,
                        'name' => 'Beistelltisch',
                        'mainDetail' => array('id' => 126, 'number' => 'SW10062',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    1 => array(
                        'id' => 66,
                        'name' => 'Garderobe',
                        'mainDetail' => array('id' => 129, 'number' => 'SW10065',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    2 => array(
                        'id' => 67,
                        'name' => 'antike Kommode',
                        'mainDetail' => array('id' => 130, 'number' => 'SW10066',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    3 => array(
                        'id' => 68,
                        'name' => 'Kommode Shabby Chic',
                        'mainDetail' => array('id' => 131, 'number' => 'SW10067',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    4 => array(
                        'id' => 69,
                        'name' => 'Wandregal',
                        'mainDetail' => array('id' => 132, 'number' => 'SW10070',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    5 => array(
                        'id' => 70,
                        'name' => 'Regal groß',
                        'mainDetail' => array('id' => 133, 'number' => 'SW10071',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    6 => array(
                        'id' => 71,
                        'name' => 'Schlüsselkasten',
                        'mainDetail' => array('id' => 134, 'number' => 'SW10072',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    7 => array(
                        'id' => 72,
                        'name' => 'Schmuckkästchen',
                        'mainDetail' => array('id' => 135, 'number' => 'SW10073',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    8 => array(
                        'id' => 73,
                        'name' => 'Spiegelregal',
                        'mainDetail' => array('id' => 136, 'number' => 'SW10074',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    9 => array(
                        'id' => 74,
                        'name' => 'Stuhl',
                        'mainDetail' => array('id' => 137, 'number' => 'SW10075',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    10 => array(
                        'id' => 75,
                        'name' => 'Esstisch',
                        'mainDetail' => array('id' => 138, 'number' => 'SW10076',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    11 => array(
                        'id' => 76,
                        'name' => 'Couchtisch rund braun',
                        'mainDetail' => array('id' => 139, 'number' => 'SW10077',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    12 => array(
                        'id' => 77,
                        'name' => 'Couchtisch eckig weiß',
                        'mainDetail' => array('id' => 140, 'number' => 'SW10078',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    13 => array(
                        'id' => 79,
                        'name' => 'Spiegel rund',
                        'mainDetail' => array('id' => 142, 'number' => 'SW10080',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    14 => array(
                        'id' => 80,
                        'name' => 'Backform gelb',
                        'mainDetail' => array('id' => 143, 'number' => 'SW10081',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    15 => array(
                        'id' => 82,
                        'name' => 'Pralinen-Backform',
                        'mainDetail' => array('id' => 145, 'number' => 'SW10083',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    16 => array(
                        'id' => 83,
                        'name' => 'Back-Set 3 teilig',
                        'mainDetail' => array('id' => 146, 'number' => 'SW10084',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    17 => array(
                        'id' => 84,
                        'name' => 'Löffel-Set',
                        'mainDetail' => array('id' => 147, 'number' => 'SW10085',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    18 => array(
                        'id' => 85,
                        'name' => 'Schneebesen',
                        'mainDetail' => array('id' => 148, 'number' => 'SW10086',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    19 => array(
                        'id' => 87,
                        'name' => 'Schüssel Style Blumen',
                        'mainDetail' => array('id' => 150, 'number' => 'SW10088',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    20 => array(
                        'id' => 86,
                        'name' => 'Schüssel Style Vögel',
                        'mainDetail' => array('id' => 149, 'number' => 'SW10087',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    21 => array(
                        'id' => 88,
                        'name' => 'Schüssel Style Ringe rot und weiß',
                        'mainDetail' => array('id' => 151, 'number' => 'SW10089',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    22 => array(
                        'id' => 89,
                        'name' => 'Teigschaber',
                        'mainDetail' => array('id' => 153, 'number' => 'SW10090.1',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    23 => array(
                        'id' => 90,
                        'name' => 'Teller Style Hühner',
                        'mainDetail' => array('id' => 155, 'number' => 'SW10091',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    24 => array(
                        'id' => 91,
                        'name' => 'Teller Style Vögel und Blumen',
                        'mainDetail' => array('id' => 156, 'number' => 'SW10092',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    25 => array(
                        'id' => 92,
                        'name' => 'Teller Style Rot und Pink',
                        'mainDetail' => array('id' => 157, 'number' => 'SW10093',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    26 => array(
                        'id' => 93,
                        'name' => 'Blumenarrangement mit Keramiktopf',
                        'mainDetail' => array('id' => 158, 'number' => 'SW10095',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    27 => array(
                        'id' => 94,
                        'name' => 'Blütenarrangement mit Rattan',
                        'mainDetail' => array('id' => 159, 'number' => 'SW10096',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    28 => array(
                        'id' => 95,
                        'name' => 'Blütenarrangement mit Rattan',
                        'mainDetail' => array('id' => 160, 'number' => 'SW10097',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    29 => array(
                        'id' => 78,
                        'name' => 'Uhr antik',
                        'mainDetail' => array('id' => 141, 'number' => 'SW10079',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    30 => array(
                        'id' => 64,
                        'name' => 'Briefkasten',
                        'mainDetail' => array('id' => 127, 'number' => 'SW10063',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    31 => array(
                        'id' => 81,
                        'name' => 'Backform pink',
                        'mainDetail' => array('id' => 144, 'number' => 'SW10082',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    32 => array(
                        'id' => 248,
                        'name' => 'Versandkosten nach Gewicht',
                        'mainDetail' => array('id' => 803, 'number' => 'SW100755036993',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    33 => array(
                        'id' => 65,
                        'name' => 'Fensterspiegel',
                        'mainDetail' => array('id' => 128, 'number' => 'SW10064',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    34 => array(
                        'id' => 98,
                        'name' => 'Fliegenklatsche grün',
                        'mainDetail' => array('id' => 163, 'number' => 'SW10101',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    35 => array(
                        'id' => 100,
                        'name' => 'Fliegenklatsche lila',
                        'mainDetail' => array('id' => 165, 'number' => 'SW10102',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    36 => array(
                        'id' => 101,
                        'name' => 'Fliegenklatsche gelb',
                        'mainDetail' => array('id' => 166, 'number' => 'SW10100',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    37 => array(
                        'id' => 97,
                        'name' => 'Eisförmchen',
                        'mainDetail' => array('id' => 162, 'number' => 'SW10099',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    38 => array(
                        'id' => 222,
                        'name' => 'Dekokissen Blume',
                        'mainDetail' => array('id' => 775, 'number' => 'SW10217',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    39 => array(
                        'id' => 224,
                        'name' => 'Dekokissen Bus',
                        'mainDetail' => array('id' => 777, 'number' => 'SW10218',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    40 => array(
                        'id' => 231,
                        'name' => 'Notizbuch New York',
                        'mainDetail' => array('id' => 786, 'number' => 'SW10223',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    41 => array(
                        'id' => 233,
                        'name' => 'Notizbuch London',
                        'mainDetail' => array('id' => 788, 'number' => 'SW10224',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    42 => array(
                        'id' => 234,
                        'name' => 'Notizbuch Paris',
                        'mainDetail' => array('id' => 789, 'number' => 'SW10225',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    43 => array(
                        'id' => 226,
                        'name' => 'Magnete ABC',
                        'mainDetail' => array('id' => 779, 'number' => 'SW10220',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    44 => array(
                        'id' => 237,
                        'name' => 'Stoffherz kariert',
                        'mainDetail' => array('id' => 792, 'number' => 'SW10228',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    45 => array(
                        'id' => 236,
                        'name' => 'Servietten',
                        'mainDetail' => array('id' => 791, 'number' => 'SW10227',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    46 => array(
                        'id' => 235,
                        'name' => 'Deko Topf',
                        'mainDetail' => array('id' => 790, 'number' => 'SW10226',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    47 => array(
                        'id' => 229,
                        'name' => 'Magnete London',
                        'mainDetail' => array('id' => 784, 'number' => 'SW10222',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    48 => array(
                        'id' => 225,
                        'name' => 'Dekokissen Vogel',
                        'mainDetail' => array('id' => 778, 'number' => 'SW10219',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                ),
                'attribute' => array(
                    'id' => 6,
                    'categoryId' => 8,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(
                    0 => array(
                        'id' => 4,
                        'active' => 1,
                        'name' => 'Wohnwelten',
                        'cols' => 3,
                        'rows' => 20,
                        'userId' => 51,
                        'cellHeight' => 185,
                        'articleHeight' => 2,
                        'containerWidth' => 808,
                        'validFrom' => null,
                        'isLandingPage' => 0,
                        'landingPageBlock' => '',
                        'landingPageTeaser' => '',
                        'seoTitle' => '',
                        'seoKeywords' => '',
                        'seoDescription' => '',
                        'validTo' => null,
                        'template' => 'Standard',
                        'showListing' => false,
                    ),
                ),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        9 => array(
            0 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 117,
                        'name' => 'Kicker Figuren Set, große Auswahl',
                        'mainDetail' => array('id' => 220, 'number' => 'SW10118.1',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    1 => array(
                        'id' => 118,
                        'name' => 'Kicker Torzähler',
                        'mainDetail' => array('id' => 236, 'number' => 'SW10119',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    2 => array(
                        'id' => 120,
                        'name' => 'Kickerball Kork',
                        'mainDetail' => array('id' => 238, 'number' => 'SW10121',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    3 => array(
                        'id' => 119,
                        'name' => 'Kickerball Standard',
                        'mainDetail' => array('id' => 237, 'number' => 'SW10120',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    4 => array(
                        'id' => 121,
                        'name' => 'Kickerball Probierset',
                        'mainDetail' => array('id' => 239, 'number' => 'SW10122',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    5 => array(
                        'id' => 113,
                        'name' => 'Kicker Champ Elite',
                        'mainDetail' => array('id' => 178, 'number' => 'SW10114',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    6 => array(
                        'id' => 114,
                        'name' => 'Kicker Champ Elite Pro (in vielen Farben)',
                        'mainDetail' => array('id' => 182, 'number' => 'SW10115.3',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    7 => array(
                        'id' => 115,
                        'name' => 'Kicker Champ Family platzsparend',
                        'mainDetail' => array('id' => 185, 'number' => 'SW10116',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    8 => array(
                        'id' => 116,
                        'name' => 'Kicker Champ, individuell gestaltbar',
                        'mainDetail' => array('id' => 186, 'number' => 'SW10117',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    9 => array(
                        'id' => 123,
                        'name' => 'Kicker XXL Champ Elite Pro',
                        'mainDetail' => array('id' => 241, 'number' => 'SW10111',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    10 => array(
                        'id' => 195,
                        'name' => 'Kicker Service Box',
                        'mainDetail' => array('id' => 435, 'number' => 'SW10194',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    11 => array(
                        'id' => 241,
                        'name' => 'Dartpfeil Steel Atomic',
                        'mainDetail' => array('id' => 796, 'number' => 'SW10232',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    12 => array(
                        'id' => 245,
                        'name' => 'Bumerang',
                        'mainDetail' => array('id' => 800, 'number' => 'SW10236',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    13 => array(
                        'id' => 246,
                        'name' => 'Dart-Set',
                        'mainDetail' => array('id' => 801, 'number' => 'SW10237',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    14 => array(
                        'id' => 242,
                        'name' => 'Dartpfeil Steel Smiley 745',
                        'mainDetail' => array('id' => 797, 'number' => 'SW10233',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    15 => array(
                        'id' => 240,
                        'name' => 'Dartscheibe Circle',
                        'mainDetail' => array('id' => 795, 'number' => 'SW10231',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    16 => array(
                        'id' => 239,
                        'name' => 'Dart Automat Standgerät',
                        'mainDetail' => array('id' => 794, 'number' => 'SW10230',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    17 => array(
                        'id' => 142,
                        'name' => 'Herrenhandschuh,halbfinger aus Peccary Leder',
                        'mainDetail' => array('id' => 289, 'number' => 'SW10142',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    18 => array(
                        'id' => 144,
                        'name' => 'Navigator Lederhaube schwarz',
                        'mainDetail' => array('id' => 291, 'number' => 'SW10144',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    19 => array(
                        'id' => 145,
                        'name' => 'Mütze Vintage Driver',
                        'mainDetail' => array('id' => 292, 'number' => 'SW10145',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    20 => array(
                        'id' => 143,
                        'name' => 'Navigator Lederhaube braun',
                        'mainDetail' => array('id' => 290, 'number' => 'SW10143',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    21 => array(
                        'id' => 134,
                        'name' => 'Balmoral Flatcap Tweed',
                        'mainDetail' => array('id' => 278, 'number' => 'SW10134',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    22 => array(
                        'id' => 135,
                        'name' => 'Damenhandschuh, halbfinger aus Peccary Leder',
                        'mainDetail' => array('id' => 279, 'number' => 'SW10135',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    23 => array(
                        'id' => 136,
                        'name' => 'Damenhandschuh aus Peccary Leder zweifarbig',
                        'mainDetail' => array('id' => 280, 'number' => 'SW10136',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    24 => array(
                        'id' => 137,
                        'name' => 'Fahrerbrille Chronos',
                        'mainDetail' => array('id' => 281, 'number' => 'SW10137',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    25 => array(
                        'id' => 148,
                        'name' => 'Reisetasche Gladstone Wildleder',
                        'mainDetail' => array('id' => 295, 'number' => 'SW10148',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    26 => array(
                        'id' => 141,
                        'name' => 'Fahrerhandschuh aus Peccary Leder',
                        'mainDetail' => array('id' => 288, 'number' => 'SW10141',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                ),
                'attribute' => array(
                    'id' => 7,
                    'categoryId' => 9,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(
                    0 => array(
                        'id' => 3,
                        'active' => 1,
                        'name' => 'Freizeitwelten',
                        'cols' => 3,
                        'rows' => 20,
                        'userId' => 51,
                        'cellHeight' => 185,
                        'articleHeight' => 2,
                        'containerWidth' => 808,
                        'validFrom' => null,
                        'isLandingPage' => 0,
                        'landingPageBlock' => '',
                        'landingPageTeaser' => '',
                        'seoTitle' => '',
                        'seoKeywords' => '',
                        'seoDescription' => '',
                        'validTo' => null,
                        'template' => 'Standard',
                        'showListing' => false,
                    ),
                ),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        10 => array(
            0 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 196,
                        'name' => 'Artikel mit ähnlichen Produkten',
                        'mainDetail' => array('id' => 436, 'number' => 'SW10195',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    1 => array(
                        'id' => 194,
                        'name' => 'Artikel mit Zubehör',
                        'mainDetail' => array('id' => 434, 'number' => 'SW10193',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    2 => array(
                        'id' => 243,
                        'name' => 'Artikel mit Emailbenachrichtigung',
                        'mainDetail' => array('id' => 798, 'number' => 'SW10234',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    3 => array(
                        'id' => 201,
                        'name' => 'Hervorgehobene Darstellung',
                        'mainDetail' => array('id' => 441, 'number' => 'SW10200',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    4 => array(
                        'id' => 200,
                        'name' => 'Artikelkennzeichnung NEU',
                        'mainDetail' => array('id' => 440, 'number' => 'SW10199',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    5 => array(
                        'id' => 199,
                        'name' => 'Artikel mit Abverkauf',
                        'mainDetail' => array('id' => 439, 'number' => 'SW10198',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    6 => array(
                        'id' => 198,
                        'name' => 'Artikel mit Bewertung',
                        'mainDetail' => array('id' => 438, 'number' => 'SW10197',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    7 => array(
                        'id' => 197,
                        'name' => 'ESD Download Artikel',
                        'mainDetail' => array('id' => 437, 'number' => 'SW10196',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    8 => array(
                        'id' => 3,
                        'name' => 'Münsterländer Aperitif 16%',
                        'mainDetail' => array('id' => 3, 'number' => 'SW10003',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    9 => array(
                        'id' => 4,
                        'name' => 'Latte Macchiato 17%',
                        'mainDetail' => array('id' => 4, 'number' => 'SW10004',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    10 => array(
                        'id' => 6,
                        'name' => 'Cigar Special 40%',
                        'mainDetail' => array('id' => 6, 'number' => 'SW10006',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    11 => array(
                        'id' => 8,
                        'name' => 'T.S. Privat 41,5 %',
                        'mainDetail' => array('id' => 14, 'number' => 'SW10008',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    12 => array(
                        'id' => 9,
                        'name' => 'Special Finish Lagerkorn X.O. 32%',
                        'mainDetail' => array('id' => 15, 'number' => 'SW10009',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    13 => array(
                        'id' => 122,
                        'name' => 'Sasse Korn 32%',
                        'mainDetail' => array('id' => 256, 'number' => 'SW10123.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    14 => array(
                        'id' => 5,
                        'name' => 'Emmelkamp Holunder Likör 18%',
                        'mainDetail' => array('id' => 252, 'number' => 'SW10005.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    15 => array(
                        'id' => 2,
                        'name' => 'Münsterländer Lagerkorn 32%',
                        'mainDetail' => array('id' => 125, 'number' => 'SW10002.3',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    16 => array(
                        'id' => 7,
                        'name' => 'Wacholder Premium extra mild 32%',
                        'mainDetail' => array('id' => 249, 'number' => 'SW10007.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    17 => array(
                        'id' => 12,
                        'name' => 'Kobra Vodka 37,5%',
                        'mainDetail' => array('id' => 18, 'number' => 'SW10012',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    18 => array(
                        'id' => 205,
                        'name' => 'Artikel mit Aufpreiskonfigurator',
                        'mainDetail' => array('id' => 726, 'number' => 'SW10204.1',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    19 => array(
                        'id' => 204,
                        'name' => 'Artikel mit Tabellenkonfigurator',
                        'mainDetail' => array('id' => 689, 'number' => 'SW10203.1',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    20 => array(
                        'id' => 203,
                        'name' => 'Artikel mit Auswahlkonfigurator',
                        'mainDetail' => array('id' => 549, 'number' => 'SW10202.1',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    21 => array(
                        'id' => 202,
                        'name' => 'Artikel mit Standardkonfigurator',
                        'mainDetail' => array('id' => 444, 'number' => 'SW10201.2',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    22 => array(
                        'id' => 206,
                        'name' => 'Artikel mit Grundpreisberechnung',
                        'mainDetail' => array('id' => 744, 'number' => 'SW10205.3',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    23 => array(
                        'id' => 209,
                        'name' => 'Staffelpreise',
                        'mainDetail' => array('id' => 747, 'number' => 'SW10208',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    24 => array(
                        'id' => 208,
                        'name' => 'Pseudopreis',
                        'mainDetail' => array('id' => 746, 'number' => 'SW10207',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    25 => array(
                        'id' => 207,
                        'name' => 'Staffelung, Mindest- / Maximalabnahme',
                        'mainDetail' => array('id' => 745, 'number' => 'SW10206',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    26 => array(
                        'id' => 221,
                        'name' => 'Versandkosten Optionen',
                        'mainDetail' => array('id' => 774, 'number' => 'SW1000299',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    27 => array(
                        'id' => 223,
                        'name' => 'Ausweichversandkosten',
                        'mainDetail' => array('id' => 780, 'number' => 'SW100718.1',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    28 => array(
                        'id' => 220,
                        'name' => 'Versandkostenfreier Artikel',
                        'mainDetail' => array('id' => 773, 'number' => 'SW10001',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    29 => array(
                        'id' => 219,
                        'name' => 'Express Versand',
                        'mainDetail' => array('id' => 772, 'number' => 'SW10185',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    30 => array(
                        'id' => 230,
                        'name' => 'Abschlag bei Zahlungsarten',
                        'mainDetail' => array('id' => 785, 'number' => 'SW10002694',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    31 => array(
                        'id' => 228,
                        'name' => 'Zahlungsarten & Riskmanagement',
                        'mainDetail' => array('id' => 783, 'number' => 'SW100025211',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    32 => array(
                        'id' => 227,
                        'name' => 'Aufschlag bei Zahlungsarten',
                        'mainDetail' => array('id' => 782, 'number' => 'SW10002841',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    33 => array(
                        'id' => 210,
                        'name' => 'Prämienartikel ab 50 Euro Warenkorb Wert',
                        'mainDetail' => array('id' => 748, 'number' => 'SW10209',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    34 => array(
                        'id' => 247,
                        'name' => 'Prämienartikel ab 100 Euro Warenkorbwert',
                        'mainDetail' => array('id' => 802, 'number' => 'SW10238',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    35 => array(
                        'id' => 211,
                        'name' => 'Prämienartikel ab 250 Euro Warenkorb Wert',
                        'mainDetail' => array('id' => 749, 'number' => 'SW10221',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    36 => array(
                        'id' => 244,
                        'name' => 'Kundengruppen Brutto / Nettopreise',
                        'mainDetail' => array('id' => 799, 'number' => 'SW10235',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                ),
                'attribute' => array(
                    'id' => 8,
                    'categoryId' => 10,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(
                    0 => array(
                        'id' => 8,
                        'active' => 1,
                        'name' => 'Beispiele',
                        'cols' => 4,
                        'rows' => 20,
                        'userId' => 59,
                        'cellHeight' => 185,
                        'articleHeight' => 2,
                        'containerWidth' => 808,
                        'validFrom' => null,
                        'isLandingPage' => 0,
                        'landingPageBlock' => '',
                        'landingPageTeaser' => '',
                        'seoTitle' => '',
                        'seoKeywords' => '',
                        'seoDescription' => '',
                        'validTo' => null,
                        'template' => 'Standard',
                        'showListing' => false,
                    ),
                ),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        17 => array(
            0 => array(
                'id' => 17,
                'parentId' => 3,
                'name' => 'Trends + News',
                'position' => 3,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Blogfunktion',
                'active' => true,
                'template' => '',
                'blog' => true,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(),
                'attribute' => array(
                    'id' => 15,
                    'categoryId' => 17,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        42 => array(
            0 => array(
                'id' => 42,
                'parentId' => 39,
                'name' => 'Trends + News',
                'position' => 0,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => true,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(),
                'attribute' => array(
                    'id' => 46,
                    'categoryId' => 42,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        43 => array(
            0 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 122,
                        'name' => 'Sasse Korn 32%',
                        'mainDetail' => array('id' => 256, 'number' => 'SW10123.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    1 => array(
                        'id' => 11,
                        'name' => 'Münsterländer Aperitif Präsent Box',
                        'mainDetail' => array('id' => 17, 'number' => 'SW10011',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    2 => array(
                        'id' => 10,
                        'name' => 'Aperitif-Glas Demi Sec',
                        'mainDetail' => array('id' => 16, 'number' => 'SW10010',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    3 => array(
                        'id' => 9,
                        'name' => 'Special Finish Lagerkorn X.O. 32%',
                        'mainDetail' => array('id' => 15, 'number' => 'SW10009',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    4 => array(
                        'id' => 8,
                        'name' => 'T.S. Privat 41,5 %',
                        'mainDetail' => array('id' => 14, 'number' => 'SW10008',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    5 => array(
                        'id' => 6,
                        'name' => 'Cigar Special 40%',
                        'mainDetail' => array('id' => 6, 'number' => 'SW10006',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    6 => array(
                        'id' => 4,
                        'name' => 'Latte Macchiato 17%',
                        'mainDetail' => array('id' => 4, 'number' => 'SW10004',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    7 => array(
                        'id' => 3,
                        'name' => 'Münsterländer Aperitif 16%',
                        'mainDetail' => array('id' => 3, 'number' => 'SW10003',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    8 => array(
                        'id' => 5,
                        'name' => 'Emmelkamp Holunder Likör 18%',
                        'mainDetail' => array('id' => 252, 'number' => 'SW10005.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    9 => array(
                        'id' => 2,
                        'name' => 'Münsterländer Lagerkorn 32%',
                        'mainDetail' => array('id' => 125, 'number' => 'SW10002.3',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    10 => array(
                        'id' => 7,
                        'name' => 'Wacholder Premium extra mild 32%',
                        'mainDetail' => array('id' => 249, 'number' => 'SW10007.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    11 => array(
                        'id' => 12,
                        'name' => 'Kobra Vodka 37,5%',
                        'mainDetail' => array('id' => 18, 'number' => 'SW10012',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    12 => array(
                        'id' => 43,
                        'name' => 'Ölwechsel',
                        'mainDetail' => array('id' => 49, 'number' => 'SW10042',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    13 => array(
                        'id' => 41,
                        'name' => 'Traubenbatterie',
                        'mainDetail' => array('id' => 47, 'number' => 'SW10040',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    14 => array(
                        'id' => 40,
                        'name' => 'Schokoleim',
                        'mainDetail' => array('id' => 46, 'number' => 'SW10039',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    15 => array(
                        'id' => 39,
                        'name' => 'Mehrzwecknudeln',
                        'mainDetail' => array('id' => 45, 'number' => 'SW10038',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    16 => array(
                        'id' => 44,
                        'name' => 'Bienenkleber',
                        'mainDetail' => array('id' => 50, 'number' => 'SW10043',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    17 => array(
                        'id' => 35,
                        'name' => 'Schwarzer Tee Geschenkset',
                        'mainDetail' => array('id' => 41, 'number' => 'SW10034',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    18 => array(
                        'id' => 34,
                        'name' => 'Pu Erh Tee Geschenkset',
                        'mainDetail' => array('id' => 40, 'number' => 'SW10033',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    19 => array(
                        'id' => 33,
                        'name' => 'Oolong Tee Geschenkset',
                        'mainDetail' => array('id' => 39, 'number' => 'SW10032',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    20 => array(
                        'id' => 32,
                        'name' => 'Jasmine Tee Geschenk Set',
                        'mainDetail' => array('id' => 38, 'number' => 'SW10031',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    21 => array(
                        'id' => 31,
                        'name' => 'Grüner Tee Geschenkset',
                        'mainDetail' => array('id' => 37, 'number' => 'SW10030',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    22 => array(
                        'id' => 21,
                        'name' => 'Jasmine Lotus Tee',
                        'mainDetail' => array('id' => 27, 'number' => 'SW10020',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    23 => array(
                        'id' => 20,
                        'name' => 'Jasmine Phoenix Tee',
                        'mainDetail' => array('id' => 26, 'number' => 'SW10019',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    24 => array(
                        'id' => 18,
                        'name' => 'Pi Lo Chun grüner Tee',
                        'mainDetail' => array('id' => 24, 'number' => 'SW10017',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    25 => array(
                        'id' => 19,
                        'name' => 'Oriental Jasmine Tee',
                        'mainDetail' => array('id' => 25, 'number' => 'SW10018',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    26 => array(
                        'id' => 17,
                        'name' => 'Mao Feng grüner Tee',
                        'mainDetail' => array('id' => 23, 'number' => 'SW10016',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    27 => array(
                        'id' => 15,
                        'name' => 'LUNG CHING grüner Tee',
                        'mainDetail' => array('id' => 21, 'number' => 'SW10015',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    28 => array(
                        'id' => 14,
                        'name' => 'Silver Yin Zhen Tee weiss',
                        'mainDetail' => array('id' => 20, 'number' => 'SW10014',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    29 => array(
                        'id' => 13,
                        'name' => 'Pai Mu Tan Tee weiss',
                        'mainDetail' => array('id' => 19, 'number' => 'SW10013',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    30 => array(
                        'id' => 36,
                        'name' => 'Weißer Tee Geschenkset',
                        'mainDetail' => array('id' => 42, 'number' => 'SW10035',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    31 => array(
                        'id' => 22,
                        'name' => 'Glas -Teetasse 0,25l',
                        'mainDetail' => array('id' => 28, 'number' => 'SW10021',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    32 => array(
                        'id' => 23,
                        'name' => 'Glasbecher',
                        'mainDetail' => array('id' => 29, 'number' => 'SW10022',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    33 => array(
                        'id' => 24,
                        'name' => 'Glas-Teekännchen',
                        'mainDetail' => array('id' => 30, 'number' => 'SW10023',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    34 => array(
                        'id' => 25,
                        'name' => 'Glas-Teekanne',
                        'mainDetail' => array('id' => 31, 'number' => 'SW10024',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    35 => array(
                        'id' => 26,
                        'name' => 'Glas Teezubereiter',
                        'mainDetail' => array('id' => 32, 'number' => 'SW10025',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                ),
                'attribute' => array(
                    'id' => 47,
                    'categoryId' => 43,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        44 => array(
            0 => array(
                'id' => 44,
                'parentId' => 39,
                'name' => 'Leisure worlds',
                'position' => 2,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 144,
                        'name' => 'Navigator Lederhaube schwarz',
                        'mainDetail' => array('id' => 291, 'number' => 'SW10144',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    1 => array(
                        'id' => 142,
                        'name' => 'Herrenhandschuh,halbfinger aus Peccary Leder',
                        'mainDetail' => array('id' => 289, 'number' => 'SW10142',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    2 => array(
                        'id' => 145,
                        'name' => 'Mütze Vintage Driver',
                        'mainDetail' => array('id' => 292, 'number' => 'SW10145',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    3 => array(
                        'id' => 143,
                        'name' => 'Navigator Lederhaube braun',
                        'mainDetail' => array('id' => 290, 'number' => 'SW10143',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    4 => array(
                        'id' => 148,
                        'name' => 'Reisetasche Gladstone Wildleder',
                        'mainDetail' => array('id' => 295, 'number' => 'SW10148',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    5 => array(
                        'id' => 241,
                        'name' => 'Dartpfeil Steel Atomic',
                        'mainDetail' => array('id' => 796, 'number' => 'SW10232',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    6 => array(
                        'id' => 118,
                        'name' => 'Kicker Torzähler',
                        'mainDetail' => array('id' => 236, 'number' => 'SW10119',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    7 => array(
                        'id' => 116,
                        'name' => 'Kicker Champ, individuell gestaltbar',
                        'mainDetail' => array('id' => 186, 'number' => 'SW10117',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    8 => array(
                        'id' => 242,
                        'name' => 'Dartpfeil Steel Smiley 745',
                        'mainDetail' => array('id' => 797, 'number' => 'SW10233',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    9 => array(
                        'id' => 240,
                        'name' => 'Dartscheibe Circle',
                        'mainDetail' => array('id' => 795, 'number' => 'SW10231',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    10 => array(
                        'id' => 239,
                        'name' => 'Dart Automat Standgerät',
                        'mainDetail' => array('id' => 794, 'number' => 'SW10230',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                ),
                'attribute' => array(
                    'id' => 48,
                    'categoryId' => 44,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        45 => array(
            0 => array(
                'id' => 45,
                'parentId' => 39,
                'name' => 'Home sweet home',
                'position' => 3,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 77,
                        'name' => 'Couchtisch eckig weiß',
                        'mainDetail' => array('id' => 140, 'number' => 'SW10078',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    1 => array(
                        'id' => 74,
                        'name' => 'Stuhl',
                        'mainDetail' => array('id' => 137, 'number' => 'SW10075',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    2 => array(
                        'id' => 69,
                        'name' => 'Wandregal',
                        'mainDetail' => array('id' => 132, 'number' => 'SW10070',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    3 => array(
                        'id' => 64,
                        'name' => 'Briefkasten',
                        'mainDetail' => array('id' => 127, 'number' => 'SW10063',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    4 => array(
                        'id' => 67,
                        'name' => 'antike Kommode',
                        'mainDetail' => array('id' => 130, 'number' => 'SW10066',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    5 => array(
                        'id' => 248,
                        'name' => 'Versandkosten nach Gewicht',
                        'mainDetail' => array('id' => 803, 'number' => 'SW100755036993',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    6 => array(
                        'id' => 101,
                        'name' => 'Fliegenklatsche gelb',
                        'mainDetail' => array('id' => 166, 'number' => 'SW10100',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    7 => array(
                        'id' => 90,
                        'name' => 'Teller Style Hühner',
                        'mainDetail' => array('id' => 155, 'number' => 'SW10091',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    8 => array(
                        'id' => 83,
                        'name' => 'Back-Set 3 teilig',
                        'mainDetail' => array('id' => 146, 'number' => 'SW10084',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    9 => array(
                        'id' => 81,
                        'name' => 'Backform pink',
                        'mainDetail' => array('id' => 144, 'number' => 'SW10082',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    10 => array(
                        'id' => 78,
                        'name' => 'Uhr antik',
                        'mainDetail' => array('id' => 141, 'number' => 'SW10079',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    11 => array(
                        'id' => 237,
                        'name' => 'Stoffherz kariert',
                        'mainDetail' => array('id' => 792, 'number' => 'SW10228',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    12 => array(
                        'id' => 236,
                        'name' => 'Servietten',
                        'mainDetail' => array('id' => 791, 'number' => 'SW10227',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    13 => array(
                        'id' => 235,
                        'name' => 'Deko Topf',
                        'mainDetail' => array('id' => 790, 'number' => 'SW10226',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    14 => array(
                        'id' => 229,
                        'name' => 'Magnete London',
                        'mainDetail' => array('id' => 784, 'number' => 'SW10222',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    15 => array(
                        'id' => 225,
                        'name' => 'Dekokissen Vogel',
                        'mainDetail' => array('id' => 778, 'number' => 'SW10219',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                ),
                'attribute' => array(
                    'id' => 49,
                    'categoryId' => 45,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        46 => array(
            0 => array(
                'id' => 46,
                'parentId' => 39,
                'name' => 'Summertime',
                'position' => 4,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 153,
                        'name' => 'Flip Flops, in mehreren Farben verfügbar',
                        'mainDetail' => array('id' => 322, 'number' => 'SW10153.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    1 => array(
                        'id' => 177,
                        'name' => 'Strandtuch Stripes für Kinder',
                        'mainDetail' => array('id' => 406, 'number' => 'SW10177',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    2 => array(
                        'id' => 160,
                        'name' => 'Sommer Sandale Ocean Blue',
                        'mainDetail' => array('id' => 364, 'number' => 'SW10160.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    3 => array(
                        'id' => 238,
                        'name' => 'Strandbag Sailor',
                        'mainDetail' => array('id' => 793, 'number' => 'SW10229',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    4 => array(
                        'id' => 213,
                        'name' => 'Surfbrett',
                        'mainDetail' => array('id' => 751, 'number' => 'SW10211',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    5 => array(
                        'id' => 178,
                        'name' => 'Strandtuch "Ibiza"',
                        'mainDetail' => array('id' => 407, 'number' => 'SW10178',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    6 => array(
                        'id' => 131,
                        'name' => 'Sonnenschirm Sombrano, 350cm',
                        'mainDetail' => array('id' => 263, 'number' => 'SW10131',),
                        'supplier' => array('id' => 11, 'name' => 'Sonnenschirm Versand',),
                    ),
                    7 => array(
                        'id' => 129,
                        'name' => 'Sonnenschirm Fortino, 270cm',
                        'mainDetail' => array('id' => 261, 'number' => 'SW10129',),
                        'supplier' => array('id' => 11, 'name' => 'Sonnenschirm Versand',),
                    ),
                    8 => array(
                        'id' => 172,
                        'name' => 'Sonnencreme Sunblocker LSF 50',
                        'mainDetail' => array('id' => 401, 'number' => 'SW10172',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    9 => array(
                        'id' => 218,
                        'name' => 'All Natural - Lemon Honey Soap',
                        'mainDetail' => array('id' => 769, 'number' => 'SW10216.1',),
                        'supplier' => array('id' => 15, 'name' => 'stop the water while using me',),
                    ),
                    10 => array(
                        'id' => 181,
                        'name' => 'Reisekoffer Set',
                        'mainDetail' => array('id' => 421, 'number' => 'SW10181',),
                        'supplier' => array('id' => 5, 'name' => 'Access Oires Sisters',),
                    ),
                    11 => array(
                        'id' => 110,
                        'name' => 'Tasche Feed Me',
                        'mainDetail' => array('id' => 175, 'number' => 'SW10113',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    12 => array(
                        'id' => 104,
                        'name' => 'Reisekoffer klein',
                        'mainDetail' => array('id' => 169, 'number' => 'SW10105',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    13 => array(
                        'id' => 102,
                        'name' => 'iPadtasche mit Stiftmappe',
                        'mainDetail' => array('id' => 167, 'number' => 'SW10103',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    14 => array(
                        'id' => 148,
                        'name' => 'Reisetasche Gladstone Wildleder',
                        'mainDetail' => array('id' => 295, 'number' => 'SW10148',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    15 => array(
                        'id' => 170,
                        'name' => 'Sonnenbrille "Red"',
                        'mainDetail' => array('id' => 394, 'number' => 'SW10170',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    16 => array(
                        'id' => 166,
                        'name' => 'Sonnenbrille Big Eyes',
                        'mainDetail' => array('id' => 390, 'number' => 'SW10166',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    17 => array(
                        'id' => 159,
                        'name' => 'Strohhut Women mit UV Schutz',
                        'mainDetail' => array('id' => 362, 'number' => 'SW10159',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    18 => array(
                        'id' => 157,
                        'name' => 'Panama Hut mit UV Schutz',
                        'mainDetail' => array('id' => 360, 'number' => 'SW10157',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                ),
                'attribute' => array(
                    'id' => 50,
                    'categoryId' => 46,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        61 => array(
            0 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 210,
                        'name' => 'Prämienartikel ab 50 Euro Warenkorb Wert',
                        'mainDetail' => array('id' => 748, 'number' => 'SW10209',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    1 => array(
                        'id' => 247,
                        'name' => 'Prämienartikel ab 100 Euro Warenkorbwert',
                        'mainDetail' => array('id' => 802, 'number' => 'SW10238',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    2 => array(
                        'id' => 211,
                        'name' => 'Prämienartikel ab 250 Euro Warenkorb Wert',
                        'mainDetail' => array('id' => 749, 'number' => 'SW10221',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    3 => array(
                        'id' => 205,
                        'name' => 'Artikel mit Aufpreiskonfigurator',
                        'mainDetail' => array('id' => 726, 'number' => 'SW10204.1',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    4 => array(
                        'id' => 204,
                        'name' => 'Artikel mit Tabellenkonfigurator',
                        'mainDetail' => array('id' => 689, 'number' => 'SW10203.1',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    5 => array(
                        'id' => 203,
                        'name' => 'Artikel mit Auswahlkonfigurator',
                        'mainDetail' => array('id' => 549, 'number' => 'SW10202.1',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    6 => array(
                        'id' => 202,
                        'name' => 'Artikel mit Standardkonfigurator',
                        'mainDetail' => array('id' => 444, 'number' => 'SW10201.2',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    7 => array(
                        'id' => 122,
                        'name' => 'Sasse Korn 32%',
                        'mainDetail' => array('id' => 256, 'number' => 'SW10123.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    8 => array(
                        'id' => 4,
                        'name' => 'Latte Macchiato 17%',
                        'mainDetail' => array('id' => 4, 'number' => 'SW10004',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    9 => array(
                        'id' => 5,
                        'name' => 'Emmelkamp Holunder Likör 18%',
                        'mainDetail' => array('id' => 252, 'number' => 'SW10005.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    10 => array(
                        'id' => 2,
                        'name' => 'Münsterländer Lagerkorn 32%',
                        'mainDetail' => array('id' => 125, 'number' => 'SW10002.3',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    11 => array(
                        'id' => 7,
                        'name' => 'Wacholder Premium extra mild 32%',
                        'mainDetail' => array('id' => 249, 'number' => 'SW10007.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    12 => array(
                        'id' => 12,
                        'name' => 'Kobra Vodka 37,5%',
                        'mainDetail' => array('id' => 18, 'number' => 'SW10012',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    13 => array(
                        'id' => 243,
                        'name' => 'Artikel mit Emailbenachrichtigung',
                        'mainDetail' => array('id' => 798, 'number' => 'SW10234',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    14 => array(
                        'id' => 201,
                        'name' => 'Hervorgehobene Darstellung',
                        'mainDetail' => array('id' => 441, 'number' => 'SW10200',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    15 => array(
                        'id' => 200,
                        'name' => 'Artikelkennzeichnung NEU',
                        'mainDetail' => array('id' => 440, 'number' => 'SW10199',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    16 => array(
                        'id' => 199,
                        'name' => 'Artikel mit Abverkauf',
                        'mainDetail' => array('id' => 439, 'number' => 'SW10198',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    17 => array(
                        'id' => 198,
                        'name' => 'Artikel mit Bewertung',
                        'mainDetail' => array('id' => 438, 'number' => 'SW10197',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    18 => array(
                        'id' => 197,
                        'name' => 'ESD Download Artikel',
                        'mainDetail' => array('id' => 437, 'number' => 'SW10196',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    19 => array(
                        'id' => 194,
                        'name' => 'Artikel mit Zubehör',
                        'mainDetail' => array('id' => 434, 'number' => 'SW10193',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    20 => array(
                        'id' => 196,
                        'name' => 'Artikel mit ähnlichen Produkten',
                        'mainDetail' => array('id' => 436, 'number' => 'SW10195',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    21 => array(
                        'id' => 230,
                        'name' => 'Abschlag bei Zahlungsarten',
                        'mainDetail' => array('id' => 785, 'number' => 'SW10002694',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    22 => array(
                        'id' => 228,
                        'name' => 'Zahlungsarten & Riskmanagement',
                        'mainDetail' => array('id' => 783, 'number' => 'SW100025211',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    23 => array(
                        'id' => 227,
                        'name' => 'Aufschlag bei Zahlungsarten',
                        'mainDetail' => array('id' => 782, 'number' => 'SW10002841',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    24 => array(
                        'id' => 221,
                        'name' => 'Versandkosten Optionen',
                        'mainDetail' => array('id' => 774, 'number' => 'SW1000299',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    25 => array(
                        'id' => 248,
                        'name' => 'Versandkosten nach Gewicht',
                        'mainDetail' => array('id' => 803, 'number' => 'SW100755036993',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    26 => array(
                        'id' => 223,
                        'name' => 'Ausweichversandkosten',
                        'mainDetail' => array('id' => 780, 'number' => 'SW100718.1',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    27 => array(
                        'id' => 220,
                        'name' => 'Versandkostenfreier Artikel',
                        'mainDetail' => array('id' => 773, 'number' => 'SW10001',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    28 => array(
                        'id' => 219,
                        'name' => 'Express Versand',
                        'mainDetail' => array('id' => 772, 'number' => 'SW10185',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    29 => array(
                        'id' => 209,
                        'name' => 'Staffelpreise',
                        'mainDetail' => array('id' => 747, 'number' => 'SW10208',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    30 => array(
                        'id' => 206,
                        'name' => 'Artikel mit Grundpreisberechnung',
                        'mainDetail' => array('id' => 744, 'number' => 'SW10205.3',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    31 => array(
                        'id' => 208,
                        'name' => 'Pseudopreis',
                        'mainDetail' => array('id' => 746, 'number' => 'SW10207',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    32 => array(
                        'id' => 207,
                        'name' => 'Staffelung, Mindest- / Maximalabnahme',
                        'mainDetail' => array('id' => 745, 'number' => 'SW10206',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                ),
                'attribute' => array(
                    'id' => 65,
                    'categoryId' => 61,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        11 => array(
            0 => array(
                'id' => 11,
                'parentId' => 5,
                'name' => 'Tees und Zubehör',
                'position' => 0,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees und Zubehör',
                'active' => true,
                'template' => 'article_listing_3col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 13,
                        'name' => 'Pai Mu Tan Tee weiss',
                        'mainDetail' => array('id' => 19, 'number' => 'SW10013',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    1 => array(
                        'id' => 21,
                        'name' => 'Jasmine Lotus Tee',
                        'mainDetail' => array('id' => 27, 'number' => 'SW10020',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    2 => array(
                        'id' => 19,
                        'name' => 'Oriental Jasmine Tee',
                        'mainDetail' => array('id' => 25, 'number' => 'SW10018',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    3 => array(
                        'id' => 20,
                        'name' => 'Jasmine Phoenix Tee',
                        'mainDetail' => array('id' => 26, 'number' => 'SW10019',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    4 => array(
                        'id' => 18,
                        'name' => 'Pi Lo Chun grüner Tee',
                        'mainDetail' => array('id' => 24, 'number' => 'SW10017',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    5 => array(
                        'id' => 17,
                        'name' => 'Mao Feng grüner Tee',
                        'mainDetail' => array('id' => 23, 'number' => 'SW10016',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    6 => array(
                        'id' => 15,
                        'name' => 'LUNG CHING grüner Tee',
                        'mainDetail' => array('id' => 21, 'number' => 'SW10015',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    7 => array(
                        'id' => 14,
                        'name' => 'Silver Yin Zhen Tee weiss',
                        'mainDetail' => array('id' => 20, 'number' => 'SW10014',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    8 => array(
                        'id' => 31,
                        'name' => 'Grüner Tee Geschenkset',
                        'mainDetail' => array('id' => 37, 'number' => 'SW10030',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    9 => array(
                        'id' => 32,
                        'name' => 'Jasmine Tee Geschenk Set',
                        'mainDetail' => array('id' => 38, 'number' => 'SW10031',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    10 => array(
                        'id' => 33,
                        'name' => 'Oolong Tee Geschenkset',
                        'mainDetail' => array('id' => 39, 'number' => 'SW10032',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    11 => array(
                        'id' => 34,
                        'name' => 'Pu Erh Tee Geschenkset',
                        'mainDetail' => array('id' => 40, 'number' => 'SW10033',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    12 => array(
                        'id' => 35,
                        'name' => 'Schwarzer Tee Geschenkset',
                        'mainDetail' => array('id' => 41, 'number' => 'SW10034',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    13 => array(
                        'id' => 36,
                        'name' => 'Weißer Tee Geschenkset',
                        'mainDetail' => array('id' => 42, 'number' => 'SW10035',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    14 => array(
                        'id' => 29,
                        'name' => 'Porzellan Teeservice',
                        'mainDetail' => array('id' => 35, 'number' => 'SW10028',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    15 => array(
                        'id' => 22,
                        'name' => 'Glas -Teetasse 0,25l',
                        'mainDetail' => array('id' => 28, 'number' => 'SW10021',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    16 => array(
                        'id' => 27,
                        'name' => 'Facil Teezubereiter',
                        'mainDetail' => array('id' => 33, 'number' => 'SW10026',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    17 => array(
                        'id' => 26,
                        'name' => 'Glas Teezubereiter',
                        'mainDetail' => array('id' => 32, 'number' => 'SW10025',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    18 => array(
                        'id' => 23,
                        'name' => 'Glasbecher',
                        'mainDetail' => array('id' => 29, 'number' => 'SW10022',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    19 => array(
                        'id' => 24,
                        'name' => 'Glas-Teekännchen',
                        'mainDetail' => array('id' => 30, 'number' => 'SW10023',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    20 => array(
                        'id' => 25,
                        'name' => 'Glas-Teekanne',
                        'mainDetail' => array('id' => 31, 'number' => 'SW10024',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    21 => array(
                        'id' => 28,
                        'name' => 'Deluxe Eisteezubereiter',
                        'mainDetail' => array('id' => 34, 'number' => 'SW10027',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    22 => array(
                        'id' => 30,
                        'name' => 'Porzellan Tee-Set in Geschenkbox',
                        'mainDetail' => array('id' => 36, 'number' => 'SW10029',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                ),
                'attribute' => array(
                    'id' => 9,
                    'categoryId' => 11,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        14 => array(
            0 => array(
                'id' => 14,
                'parentId' => 5,
                'name' => 'Edelbrände',
                'position' => 0,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Die besten Edelbrände',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 10,
                        'name' => 'Aperitif-Glas Demi Sec',
                        'mainDetail' => array('id' => 16, 'number' => 'SW10010',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    1 => array(
                        'id' => 3,
                        'name' => 'Münsterländer Aperitif 16%',
                        'mainDetail' => array('id' => 3, 'number' => 'SW10003',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    2 => array(
                        'id' => 4,
                        'name' => 'Latte Macchiato 17%',
                        'mainDetail' => array('id' => 4, 'number' => 'SW10004',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    3 => array(
                        'id' => 6,
                        'name' => 'Cigar Special 40%',
                        'mainDetail' => array('id' => 6, 'number' => 'SW10006',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    4 => array(
                        'id' => 9,
                        'name' => 'Special Finish Lagerkorn X.O. 32%',
                        'mainDetail' => array('id' => 15, 'number' => 'SW10009',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    5 => array(
                        'id' => 8,
                        'name' => 'T.S. Privat 41,5 %',
                        'mainDetail' => array('id' => 14, 'number' => 'SW10008',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    6 => array(
                        'id' => 11,
                        'name' => 'Münsterländer Aperitif Präsent Box',
                        'mainDetail' => array('id' => 17, 'number' => 'SW10011',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    7 => array(
                        'id' => 122,
                        'name' => 'Sasse Korn 32%',
                        'mainDetail' => array('id' => 256, 'number' => 'SW10123.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    8 => array(
                        'id' => 5,
                        'name' => 'Emmelkamp Holunder Likör 18%',
                        'mainDetail' => array('id' => 252, 'number' => 'SW10005.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    9 => array(
                        'id' => 2,
                        'name' => 'Münsterländer Lagerkorn 32%',
                        'mainDetail' => array('id' => 125, 'number' => 'SW10002.3',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    10 => array(
                        'id' => 7,
                        'name' => 'Wacholder Premium extra mild 32%',
                        'mainDetail' => array('id' => 249, 'number' => 'SW10007.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    11 => array(
                        'id' => 12,
                        'name' => 'Kobra Vodka 37,5%',
                        'mainDetail' => array('id' => 18, 'number' => 'SW10012',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                ),
                'attribute' => array(
                    'id' => 12,
                    'categoryId' => 14,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        15 => array(
            0 => array(
                'id' => 15,
                'parentId' => 5,
                'name' => 'Köstlichkeiten',
                'position' => 0,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Köstlichkeiten',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 37,
                        'name' => 'Esslack',
                        'mainDetail' => array('id' => 43, 'number' => 'SW10036',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    1 => array(
                        'id' => 39,
                        'name' => 'Mehrzwecknudeln',
                        'mainDetail' => array('id' => 45, 'number' => 'SW10038',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    2 => array(
                        'id' => 41,
                        'name' => 'Traubenbatterie',
                        'mainDetail' => array('id' => 47, 'number' => 'SW10040',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    3 => array(
                        'id' => 42,
                        'name' => 'Tubenhonig',
                        'mainDetail' => array('id' => 48, 'number' => 'SW10041',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    4 => array(
                        'id' => 38,
                        'name' => 'Kraftstoff',
                        'mainDetail' => array('id' => 44, 'number' => 'SW10037',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    5 => array(
                        'id' => 40,
                        'name' => 'Schokoleim',
                        'mainDetail' => array('id' => 46, 'number' => 'SW10039',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    6 => array(
                        'id' => 43,
                        'name' => 'Ölwechsel',
                        'mainDetail' => array('id' => 49, 'number' => 'SW10042',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    7 => array(
                        'id' => 272,
                        'name' => 'Spachtelmasse',
                        'mainDetail' => array('id' => 827, 'number' => 'SW10239',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    8 => array(
                        'id' => 44,
                        'name' => 'Bienenkleber',
                        'mainDetail' => array('id' => 50, 'number' => 'SW10043',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                ),
                'attribute' => array(
                    'id' => 13,
                    'categoryId' => 15,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        16 => array(
            0 => array(
                'id' => 16,
                'parentId' => 9,
                'name' => 'Entertainment',
                'position' => 1,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 117,
                        'name' => 'Kicker Figuren Set, große Auswahl',
                        'mainDetail' => array('id' => 220, 'number' => 'SW10118.1',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    1 => array(
                        'id' => 118,
                        'name' => 'Kicker Torzähler',
                        'mainDetail' => array('id' => 236, 'number' => 'SW10119',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    2 => array(
                        'id' => 120,
                        'name' => 'Kickerball Kork',
                        'mainDetail' => array('id' => 238, 'number' => 'SW10121',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    3 => array(
                        'id' => 119,
                        'name' => 'Kickerball Standard',
                        'mainDetail' => array('id' => 237, 'number' => 'SW10120',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    4 => array(
                        'id' => 121,
                        'name' => 'Kickerball Probierset',
                        'mainDetail' => array('id' => 239, 'number' => 'SW10122',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    5 => array(
                        'id' => 113,
                        'name' => 'Kicker Champ Elite',
                        'mainDetail' => array('id' => 178, 'number' => 'SW10114',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    6 => array(
                        'id' => 114,
                        'name' => 'Kicker Champ Elite Pro (in vielen Farben)',
                        'mainDetail' => array('id' => 182, 'number' => 'SW10115.3',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    7 => array(
                        'id' => 115,
                        'name' => 'Kicker Champ Family platzsparend',
                        'mainDetail' => array('id' => 185, 'number' => 'SW10116',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    8 => array(
                        'id' => 116,
                        'name' => 'Kicker Champ, individuell gestaltbar',
                        'mainDetail' => array('id' => 186, 'number' => 'SW10117',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    9 => array(
                        'id' => 123,
                        'name' => 'Kicker XXL Champ Elite Pro',
                        'mainDetail' => array('id' => 241, 'number' => 'SW10111',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    10 => array(
                        'id' => 195,
                        'name' => 'Kicker Service Box',
                        'mainDetail' => array('id' => 435, 'number' => 'SW10194',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    11 => array(
                        'id' => 241,
                        'name' => 'Dartpfeil Steel Atomic',
                        'mainDetail' => array('id' => 796, 'number' => 'SW10232',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    12 => array(
                        'id' => 245,
                        'name' => 'Bumerang',
                        'mainDetail' => array('id' => 800, 'number' => 'SW10236',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    13 => array(
                        'id' => 246,
                        'name' => 'Dart-Set',
                        'mainDetail' => array('id' => 801, 'number' => 'SW10237',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    14 => array(
                        'id' => 242,
                        'name' => 'Dartpfeil Steel Smiley 745',
                        'mainDetail' => array('id' => 797, 'number' => 'SW10233',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    15 => array(
                        'id' => 240,
                        'name' => 'Dartscheibe Circle',
                        'mainDetail' => array('id' => 795, 'number' => 'SW10231',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    16 => array(
                        'id' => 239,
                        'name' => 'Dart Automat Standgerät',
                        'mainDetail' => array('id' => 794, 'number' => 'SW10230',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                ),
                'attribute' => array(
                    'id' => 14,
                    'categoryId' => 16,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        19 => array(
            0 => array(
                'id' => 19,
                'parentId' => 10,
                'name' => 'Crossselling',
                'position' => 6,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Crossselling',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 196,
                        'name' => 'Artikel mit ähnlichen Produkten',
                        'mainDetail' => array('id' => 436, 'number' => 'SW10195',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    1 => array(
                        'id' => 194,
                        'name' => 'Artikel mit Zubehör',
                        'mainDetail' => array('id' => 434, 'number' => 'SW10193',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                ),
                'attribute' => array(
                    'id' => 17,
                    'categoryId' => 19,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        20 => array(
            0 => array(
                'id' => 20,
                'parentId' => 10,
                'name' => 'Darstellung',
                'position' => 5,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Artikeldarstellung im Listing.',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 243,
                        'name' => 'Artikel mit Emailbenachrichtigung',
                        'mainDetail' => array('id' => 798, 'number' => 'SW10234',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    1 => array(
                        'id' => 201,
                        'name' => 'Hervorgehobene Darstellung',
                        'mainDetail' => array('id' => 441, 'number' => 'SW10200',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    2 => array(
                        'id' => 200,
                        'name' => 'Artikelkennzeichnung NEU',
                        'mainDetail' => array('id' => 440, 'number' => 'SW10199',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    3 => array(
                        'id' => 199,
                        'name' => 'Artikel mit Abverkauf',
                        'mainDetail' => array('id' => 439, 'number' => 'SW10198',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    4 => array(
                        'id' => 198,
                        'name' => 'Artikel mit Bewertung',
                        'mainDetail' => array('id' => 438, 'number' => 'SW10197',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    5 => array(
                        'id' => 197,
                        'name' => 'ESD Download Artikel',
                        'mainDetail' => array('id' => 437, 'number' => 'SW10196',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                ),
                'attribute' => array(
                    'id' => 18,
                    'categoryId' => 20,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        21 => array(
            0 => array(
                'id' => 21,
                'parentId' => 10,
                'name' => 'Produktvergleiche & Filter',
                'position' => 4,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Eigenschaften und Filter',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 3,
                        'name' => 'Münsterländer Aperitif 16%',
                        'mainDetail' => array('id' => 3, 'number' => 'SW10003',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    1 => array(
                        'id' => 4,
                        'name' => 'Latte Macchiato 17%',
                        'mainDetail' => array('id' => 4, 'number' => 'SW10004',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    2 => array(
                        'id' => 6,
                        'name' => 'Cigar Special 40%',
                        'mainDetail' => array('id' => 6, 'number' => 'SW10006',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    3 => array(
                        'id' => 8,
                        'name' => 'T.S. Privat 41,5 %',
                        'mainDetail' => array('id' => 14, 'number' => 'SW10008',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    4 => array(
                        'id' => 9,
                        'name' => 'Special Finish Lagerkorn X.O. 32%',
                        'mainDetail' => array('id' => 15, 'number' => 'SW10009',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    5 => array(
                        'id' => 122,
                        'name' => 'Sasse Korn 32%',
                        'mainDetail' => array('id' => 256, 'number' => 'SW10123.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    6 => array(
                        'id' => 5,
                        'name' => 'Emmelkamp Holunder Likör 18%',
                        'mainDetail' => array('id' => 252, 'number' => 'SW10005.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    7 => array(
                        'id' => 2,
                        'name' => 'Münsterländer Lagerkorn 32%',
                        'mainDetail' => array('id' => 125, 'number' => 'SW10002.3',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    8 => array(
                        'id' => 7,
                        'name' => 'Wacholder Premium extra mild 32%',
                        'mainDetail' => array('id' => 249, 'number' => 'SW10007.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    9 => array(
                        'id' => 12,
                        'name' => 'Kobra Vodka 37,5%',
                        'mainDetail' => array('id' => 18, 'number' => 'SW10012',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                ),
                'attribute' => array(
                    'id' => 19,
                    'categoryId' => 21,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        22 => array(
            0 => array(
                'id' => 22,
                'parentId' => 10,
                'name' => 'Konfiguratorartikel',
                'position' => 2,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Das Plugin Artikelkonfigurator',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 205,
                        'name' => 'Artikel mit Aufpreiskonfigurator',
                        'mainDetail' => array('id' => 726, 'number' => 'SW10204.1',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    1 => array(
                        'id' => 204,
                        'name' => 'Artikel mit Tabellenkonfigurator',
                        'mainDetail' => array('id' => 689, 'number' => 'SW10203.1',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    2 => array(
                        'id' => 203,
                        'name' => 'Artikel mit Auswahlkonfigurator',
                        'mainDetail' => array('id' => 549, 'number' => 'SW10202.1',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    3 => array(
                        'id' => 202,
                        'name' => 'Artikel mit Standardkonfigurator',
                        'mainDetail' => array('id' => 444, 'number' => 'SW10201.2',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                ),
                'attribute' => array(
                    'id' => 20,
                    'categoryId' => 22,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        23 => array(
            0 => array(
                'id' => 23,
                'parentId' => 10,
                'name' => 'Preisgestaltung',
                'position' => 10,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Möglichkeiten der Preisgestaltung',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 206,
                        'name' => 'Artikel mit Grundpreisberechnung',
                        'mainDetail' => array('id' => 744, 'number' => 'SW10205.3',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    1 => array(
                        'id' => 209,
                        'name' => 'Staffelpreise',
                        'mainDetail' => array('id' => 747, 'number' => 'SW10208',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    2 => array(
                        'id' => 208,
                        'name' => 'Pseudopreis',
                        'mainDetail' => array('id' => 746, 'number' => 'SW10207',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    3 => array(
                        'id' => 207,
                        'name' => 'Staffelung, Mindest- / Maximalabnahme',
                        'mainDetail' => array('id' => 745, 'number' => 'SW10206',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                ),
                'attribute' => array(
                    'id' => 21,
                    'categoryId' => 23,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        24 => array(
            0 => array(
                'id' => 24,
                'parentId' => 10,
                'name' => 'Versandkosten',
                'position' => 7,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Versandkosteneinstellungen',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 221,
                        'name' => 'Versandkosten Optionen',
                        'mainDetail' => array('id' => 774, 'number' => 'SW1000299',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    1 => array(
                        'id' => 223,
                        'name' => 'Ausweichversandkosten',
                        'mainDetail' => array('id' => 780, 'number' => 'SW100718.1',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    2 => array(
                        'id' => 220,
                        'name' => 'Versandkostenfreier Artikel',
                        'mainDetail' => array('id' => 773, 'number' => 'SW10001',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    3 => array(
                        'id' => 219,
                        'name' => 'Express Versand',
                        'mainDetail' => array('id' => 772, 'number' => 'SW10185',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                ),
                'attribute' => array(
                    'id' => 22,
                    'categoryId' => 24,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        25 => array(
            0 => array(
                'id' => 25,
                'parentId' => 10,
                'name' => 'Zahlungsarten',
                'position' => 8,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Zahlungsarten & Riskmanagement',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 230,
                        'name' => 'Abschlag bei Zahlungsarten',
                        'mainDetail' => array('id' => 785, 'number' => 'SW10002694',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    1 => array(
                        'id' => 228,
                        'name' => 'Zahlungsarten & Riskmanagement',
                        'mainDetail' => array('id' => 783, 'number' => 'SW100025211',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    2 => array(
                        'id' => 227,
                        'name' => 'Aufschlag bei Zahlungsarten',
                        'mainDetail' => array('id' => 782, 'number' => 'SW10002841',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                ),
                'attribute' => array(
                    'id' => 23,
                    'categoryId' => 25,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        27 => array(
            0 => array(
                'id' => 27,
                'parentId' => 10,
                'name' => 'In Kürze verfügbar',
                'position' => 0,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'In Kürze verfügbar',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(),
                'attribute' => array(
                    'id' => 25,
                    'categoryId' => 27,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(
                    0 => array(
                        'id' => 12,
                        'active' => 1,
                        'name' => 'in Kürze verfügbar',
                        'cols' => 4,
                        'rows' => 20,
                        'userId' => 52,
                        'cellHeight' => 185,
                        'articleHeight' => 2,
                        'containerWidth' => 808,
                        'validFrom' => null,
                        'isLandingPage' => 0,
                        'landingPageBlock' => '',
                        'landingPageTeaser' => '',
                        'seoTitle' => '',
                        'seoKeywords' => '',
                        'seoDescription' => '',
                        'validTo' => null,
                        'template' => 'Standard',
                        'showListing' => false,
                    ),
                ),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        30 => array(
            0 => array(
                'id' => 30,
                'parentId' => 10,
                'name' => 'Kundenbindung',
                'position' => 3,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Funktionen zur Kundenbindung',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 210,
                        'name' => 'Prämienartikel ab 50 Euro Warenkorb Wert',
                        'mainDetail' => array('id' => 748, 'number' => 'SW10209',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    1 => array(
                        'id' => 247,
                        'name' => 'Prämienartikel ab 100 Euro Warenkorbwert',
                        'mainDetail' => array('id' => 802, 'number' => 'SW10238',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    2 => array(
                        'id' => 211,
                        'name' => 'Prämienartikel ab 250 Euro Warenkorb Wert',
                        'mainDetail' => array('id' => 749, 'number' => 'SW10221',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                ),
                'attribute' => array(
                    'id' => 28,
                    'categoryId' => 30,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        31 => array(
            0 => array(
                'id' => 31,
                'parentId' => 9,
                'name' => 'Vintage',
                'position' => 0,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 142,
                        'name' => 'Herrenhandschuh,halbfinger aus Peccary Leder',
                        'mainDetail' => array('id' => 289, 'number' => 'SW10142',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    1 => array(
                        'id' => 144,
                        'name' => 'Navigator Lederhaube schwarz',
                        'mainDetail' => array('id' => 291, 'number' => 'SW10144',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    2 => array(
                        'id' => 145,
                        'name' => 'Mütze Vintage Driver',
                        'mainDetail' => array('id' => 292, 'number' => 'SW10145',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    3 => array(
                        'id' => 143,
                        'name' => 'Navigator Lederhaube braun',
                        'mainDetail' => array('id' => 290, 'number' => 'SW10143',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    4 => array(
                        'id' => 134,
                        'name' => 'Balmoral Flatcap Tweed',
                        'mainDetail' => array('id' => 278, 'number' => 'SW10134',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    5 => array(
                        'id' => 135,
                        'name' => 'Damenhandschuh, halbfinger aus Peccary Leder',
                        'mainDetail' => array('id' => 279, 'number' => 'SW10135',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    6 => array(
                        'id' => 136,
                        'name' => 'Damenhandschuh aus Peccary Leder zweifarbig',
                        'mainDetail' => array('id' => 280, 'number' => 'SW10136',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    7 => array(
                        'id' => 137,
                        'name' => 'Fahrerbrille Chronos',
                        'mainDetail' => array('id' => 281, 'number' => 'SW10137',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    8 => array(
                        'id' => 148,
                        'name' => 'Reisetasche Gladstone Wildleder',
                        'mainDetail' => array('id' => 295, 'number' => 'SW10148',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    9 => array(
                        'id' => 141,
                        'name' => 'Fahrerhandschuh aus Peccary Leder',
                        'mainDetail' => array('id' => 288, 'number' => 'SW10141',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                ),
                'attribute' => array(
                    'id' => 35,
                    'categoryId' => 31,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        32 => array(
            0 => array(
                'id' => 32,
                'parentId' => 8,
                'name' => 'Möbel',
                'position' => 0,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Möbel',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 63,
                        'name' => 'Beistelltisch',
                        'mainDetail' => array('id' => 126, 'number' => 'SW10062',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    1 => array(
                        'id' => 66,
                        'name' => 'Garderobe',
                        'mainDetail' => array('id' => 129, 'number' => 'SW10065',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    2 => array(
                        'id' => 67,
                        'name' => 'antike Kommode',
                        'mainDetail' => array('id' => 130, 'number' => 'SW10066',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    3 => array(
                        'id' => 68,
                        'name' => 'Kommode Shabby Chic',
                        'mainDetail' => array('id' => 131, 'number' => 'SW10067',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    4 => array(
                        'id' => 69,
                        'name' => 'Wandregal',
                        'mainDetail' => array('id' => 132, 'number' => 'SW10070',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    5 => array(
                        'id' => 70,
                        'name' => 'Regal groß',
                        'mainDetail' => array('id' => 133, 'number' => 'SW10071',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    6 => array(
                        'id' => 71,
                        'name' => 'Schlüsselkasten',
                        'mainDetail' => array('id' => 134, 'number' => 'SW10072',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    7 => array(
                        'id' => 72,
                        'name' => 'Schmuckkästchen',
                        'mainDetail' => array('id' => 135, 'number' => 'SW10073',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    8 => array(
                        'id' => 73,
                        'name' => 'Spiegelregal',
                        'mainDetail' => array('id' => 136, 'number' => 'SW10074',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    9 => array(
                        'id' => 74,
                        'name' => 'Stuhl',
                        'mainDetail' => array('id' => 137, 'number' => 'SW10075',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    10 => array(
                        'id' => 75,
                        'name' => 'Esstisch',
                        'mainDetail' => array('id' => 138, 'number' => 'SW10076',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    11 => array(
                        'id' => 76,
                        'name' => 'Couchtisch rund braun',
                        'mainDetail' => array('id' => 139, 'number' => 'SW10077',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    12 => array(
                        'id' => 77,
                        'name' => 'Couchtisch eckig weiß',
                        'mainDetail' => array('id' => 140, 'number' => 'SW10078',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    13 => array(
                        'id' => 64,
                        'name' => 'Briefkasten',
                        'mainDetail' => array('id' => 127, 'number' => 'SW10063',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    14 => array(
                        'id' => 248,
                        'name' => 'Versandkosten nach Gewicht',
                        'mainDetail' => array('id' => 803, 'number' => 'SW100755036993',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    15 => array(
                        'id' => 65,
                        'name' => 'Fensterspiegel',
                        'mainDetail' => array('id' => 128, 'number' => 'SW10064',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                ),
                'attribute' => array(
                    'id' => 36,
                    'categoryId' => 32,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        33 => array(
            0 => array(
                'id' => 33,
                'parentId' => 8,
                'name' => 'Küchenzubehör',
                'position' => 0,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Vielfältiges Zubehör für Ihre Küche',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 78,
                        'name' => 'Uhr antik',
                        'mainDetail' => array('id' => 141, 'number' => 'SW10079',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    1 => array(
                        'id' => 80,
                        'name' => 'Backform gelb',
                        'mainDetail' => array('id' => 143, 'number' => 'SW10081',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    2 => array(
                        'id' => 82,
                        'name' => 'Pralinen-Backform',
                        'mainDetail' => array('id' => 145, 'number' => 'SW10083',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    3 => array(
                        'id' => 89,
                        'name' => 'Teigschaber',
                        'mainDetail' => array('id' => 153, 'number' => 'SW10090.1',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    4 => array(
                        'id' => 90,
                        'name' => 'Teller Style Hühner',
                        'mainDetail' => array('id' => 155, 'number' => 'SW10091',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    5 => array(
                        'id' => 91,
                        'name' => 'Teller Style Vögel und Blumen',
                        'mainDetail' => array('id' => 156, 'number' => 'SW10092',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    6 => array(
                        'id' => 92,
                        'name' => 'Teller Style Rot und Pink',
                        'mainDetail' => array('id' => 157, 'number' => 'SW10093',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    7 => array(
                        'id' => 83,
                        'name' => 'Back-Set 3 teilig',
                        'mainDetail' => array('id' => 146, 'number' => 'SW10084',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    8 => array(
                        'id' => 84,
                        'name' => 'Löffel-Set',
                        'mainDetail' => array('id' => 147, 'number' => 'SW10085',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    9 => array(
                        'id' => 85,
                        'name' => 'Schneebesen',
                        'mainDetail' => array('id' => 148, 'number' => 'SW10086',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    10 => array(
                        'id' => 86,
                        'name' => 'Schüssel Style Vögel',
                        'mainDetail' => array('id' => 149, 'number' => 'SW10087',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    11 => array(
                        'id' => 87,
                        'name' => 'Schüssel Style Blumen',
                        'mainDetail' => array('id' => 150, 'number' => 'SW10088',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    12 => array(
                        'id' => 88,
                        'name' => 'Schüssel Style Ringe rot und weiß',
                        'mainDetail' => array('id' => 151, 'number' => 'SW10089',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    13 => array(
                        'id' => 98,
                        'name' => 'Fliegenklatsche grün',
                        'mainDetail' => array('id' => 163, 'number' => 'SW10101',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    14 => array(
                        'id' => 100,
                        'name' => 'Fliegenklatsche lila',
                        'mainDetail' => array('id' => 165, 'number' => 'SW10102',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    15 => array(
                        'id' => 101,
                        'name' => 'Fliegenklatsche gelb',
                        'mainDetail' => array('id' => 166, 'number' => 'SW10100',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    16 => array(
                        'id' => 81,
                        'name' => 'Backform pink',
                        'mainDetail' => array('id' => 144, 'number' => 'SW10082',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    17 => array(
                        'id' => 97,
                        'name' => 'Eisförmchen',
                        'mainDetail' => array('id' => 162, 'number' => 'SW10099',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                ),
                'attribute' => array(
                    'id' => 37,
                    'categoryId' => 33,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        34 => array(
            0 => array(
                'id' => 34,
                'parentId' => 6,
                'name' => 'Beachwear',
                'position' => 0,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 173,
                        'name' => 'Strandkleid Flower Power',
                        'mainDetail' => array('id' => 402, 'number' => 'SW10173',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    1 => array(
                        'id' => 174,
                        'name' => 'Strandkleid Short Red',
                        'mainDetail' => array('id' => 403, 'number' => 'SW10174',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    2 => array(
                        'id' => 153,
                        'name' => 'Flip Flops, in mehreren Farben verfügbar',
                        'mainDetail' => array('id' => 322, 'number' => 'SW10153.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    3 => array(
                        'id' => 156,
                        'name' => 'Flip Flops Deep Red',
                        'mainDetail' => array('id' => 346, 'number' => 'SW10156.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    4 => array(
                        'id' => 160,
                        'name' => 'Sommer Sandale Ocean Blue',
                        'mainDetail' => array('id' => 364, 'number' => 'SW10160.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    5 => array(
                        'id' => 161,
                        'name' => 'Sommer-Sandale Leder Rot-Braun',
                        'mainDetail' => array('id' => 372, 'number' => 'SW10161.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    6 => array(
                        'id' => 162,
                        'name' => 'Sommer-Sandale Pink',
                        'mainDetail' => array('id' => 380, 'number' => 'SW10162.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    7 => array(
                        'id' => 96,
                        'name' => 'Strandbag',
                        'mainDetail' => array('id' => 161, 'number' => 'SW10098',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    8 => array(
                        'id' => 108,
                        'name' => 'Strandbag',
                        'mainDetail' => array('id' => 173, 'number' => 'SW10109',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    9 => array(
                        'id' => 109,
                        'name' => 'Strandbag Fantasy',
                        'mainDetail' => array('id' => 174, 'number' => 'SW10110',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    10 => array(
                        'id' => 175,
                        'name' => 'Strandtuch Sunny',
                        'mainDetail' => array('id' => 404, 'number' => 'SW10175',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    11 => array(
                        'id' => 176,
                        'name' => 'Strandtuch Gras-Green',
                        'mainDetail' => array('id' => 405, 'number' => 'SW10176',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    12 => array(
                        'id' => 177,
                        'name' => 'Strandtuch Stripes für Kinder',
                        'mainDetail' => array('id' => 406, 'number' => 'SW10177',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    13 => array(
                        'id' => 179,
                        'name' => 'Strandtuch in mehreren Farben',
                        'mainDetail' => array('id' => 409, 'number' => 'SW10179.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    14 => array(
                        'id' => 238,
                        'name' => 'Strandbag Sailor',
                        'mainDetail' => array('id' => 793, 'number' => 'SW10229',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    15 => array(
                        'id' => 213,
                        'name' => 'Surfbrett',
                        'mainDetail' => array('id' => 751, 'number' => 'SW10211',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    16 => array(
                        'id' => 178,
                        'name' => 'Strandtuch "Ibiza"',
                        'mainDetail' => array('id' => 407, 'number' => 'SW10178',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    17 => array(
                        'id' => 155,
                        'name' => 'Flip Flop Sunshine Yellow',
                        'mainDetail' => array('id' => 353, 'number' => 'SW10155.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                ),
                'attribute' => array(
                    'id' => 38,
                    'categoryId' => 34,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        35 => array(
            0 => array(
                'id' => 35,
                'parentId' => 6,
                'name' => 'Beauty & Care',
                'position' => 0,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 214,
                        'name' => 'All Natural - Rosemary Grapefruit Conditioner',
                        'mainDetail' => array('id' => 753, 'number' => 'SW10212.1',),
                        'supplier' => array('id' => 15, 'name' => 'stop the water while using me',),
                    ),
                    1 => array(
                        'id' => 216,
                        'name' => 'All Natural - Sesame Sage Bodylotion',
                        'mainDetail' => array('id' => 761, 'number' => 'SW10214.1',),
                        'supplier' => array('id' => 15, 'name' => 'stop the water while using me',),
                    ),
                    2 => array(
                        'id' => 217,
                        'name' => 'All Natural - Orange Wild Herbs Shower Gel',
                        'mainDetail' => array('id' => 766, 'number' => 'SW10215.1',),
                        'supplier' => array('id' => 15, 'name' => 'stop the water while using me',),
                    ),
                    3 => array(
                        'id' => 215,
                        'name' => 'All Natural - Rosemary Grapefruit Shampoo',
                        'mainDetail' => array('id' => 757, 'number' => 'SW10213.1',),
                        'supplier' => array('id' => 15, 'name' => 'stop the water while using me',),
                    ),
                    4 => array(
                        'id' => 171,
                        'name' => 'Sonnencreme ab  LSF 10',
                        'mainDetail' => array('id' => 396, 'number' => 'SW10171.1',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    5 => array(
                        'id' => 172,
                        'name' => 'Sonnencreme Sunblocker LSF 50',
                        'mainDetail' => array('id' => 401, 'number' => 'SW10172',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    6 => array(
                        'id' => 128,
                        'name' => 'Sonnenschirm Alu-Style, 270cm',
                        'mainDetail' => array('id' => 260, 'number' => 'SW10128',),
                        'supplier' => array('id' => 11, 'name' => 'Sonnenschirm Versand',),
                    ),
                    7 => array(
                        'id' => 129,
                        'name' => 'Sonnenschirm Fortino, 270cm',
                        'mainDetail' => array('id' => 261, 'number' => 'SW10129',),
                        'supplier' => array('id' => 11, 'name' => 'Sonnenschirm Versand',),
                    ),
                    8 => array(
                        'id' => 130,
                        'name' => 'Sonnenschirm Pendalex V+, 280cm',
                        'mainDetail' => array('id' => 262, 'number' => 'SW10130',),
                        'supplier' => array('id' => 11, 'name' => 'Sonnenschirm Versand',),
                    ),
                    9 => array(
                        'id' => 131,
                        'name' => 'Sonnenschirm Sombrano, 350cm',
                        'mainDetail' => array('id' => 263, 'number' => 'SW10131',),
                        'supplier' => array('id' => 11, 'name' => 'Sonnenschirm Versand',),
                    ),
                    10 => array(
                        'id' => 132,
                        'name' => 'Sonnenschirm Sunwing C+, 260cm',
                        'mainDetail' => array('id' => 264, 'number' => 'SW10132',),
                        'supplier' => array('id' => 11, 'name' => 'Sonnenschirm Versand',),
                    ),
                    11 => array(
                        'id' => 218,
                        'name' => 'All Natural - Lemon Honey Soap',
                        'mainDetail' => array('id' => 769, 'number' => 'SW10216.1',),
                        'supplier' => array('id' => 15, 'name' => 'stop the water while using me',),
                    ),
                ),
                'attribute' => array(
                    'id' => 39,
                    'categoryId' => 35,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        36 => array(
            0 => array(
                'id' => 36,
                'parentId' => 6,
                'name' => 'On World Tour',
                'position' => 0,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 102,
                        'name' => 'iPadtasche mit Stiftmappe',
                        'mainDetail' => array('id' => 167, 'number' => 'SW10103',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    1 => array(
                        'id' => 105,
                        'name' => 'Kosmetiktasche',
                        'mainDetail' => array('id' => 170, 'number' => 'SW10107',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    2 => array(
                        'id' => 106,
                        'name' => 'Kosmetiktasche',
                        'mainDetail' => array('id' => 171, 'number' => 'SW10108',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    3 => array(
                        'id' => 107,
                        'name' => 'Kosmetiktasche',
                        'mainDetail' => array('id' => 172, 'number' => 'SW10106',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    4 => array(
                        'id' => 110,
                        'name' => 'Tasche Feed Me',
                        'mainDetail' => array('id' => 175, 'number' => 'SW10113',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    5 => array(
                        'id' => 112,
                        'name' => 'Tasche Remember Me',
                        'mainDetail' => array('id' => 177, 'number' => 'SW10112',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    6 => array(
                        'id' => 103,
                        'name' => 'Reisekoffer groß',
                        'mainDetail' => array('id' => 168, 'number' => 'SW10104',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    7 => array(
                        'id' => 104,
                        'name' => 'Reisekoffer klein',
                        'mainDetail' => array('id' => 169, 'number' => 'SW10105',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    8 => array(
                        'id' => 180,
                        'name' => 'Reisekoffer, in mehreren Farben',
                        'mainDetail' => array('id' => 417, 'number' => 'SW10180.1',),
                        'supplier' => array('id' => 5, 'name' => 'Access Oires Sisters',),
                    ),
                    9 => array(
                        'id' => 181,
                        'name' => 'Reisekoffer Set',
                        'mainDetail' => array('id' => 421, 'number' => 'SW10181',),
                        'supplier' => array('id' => 5, 'name' => 'Access Oires Sisters',),
                    ),
                    10 => array(
                        'id' => 148,
                        'name' => 'Reisetasche Gladstone Wildleder',
                        'mainDetail' => array('id' => 295, 'number' => 'SW10148',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                ),
                'attribute' => array(
                    'id' => 40,
                    'categoryId' => 36,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        37 => array(
            0 => array(
                'id' => 37,
                'parentId' => 6,
                'name' => 'Accessoires',
                'position' => 0,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 163,
                        'name' => 'Sommerschal Flower Power',
                        'mainDetail' => array('id' => 387, 'number' => 'SW10163',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    1 => array(
                        'id' => 164,
                        'name' => 'Sommerschal Fresh Green',
                        'mainDetail' => array('id' => 388, 'number' => 'SW10164',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    2 => array(
                        'id' => 165,
                        'name' => 'Sommerschal Light Red aus Seide',
                        'mainDetail' => array('id' => 389, 'number' => 'SW10165',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    3 => array(
                        'id' => 157,
                        'name' => 'Panama Hut mit UV Schutz',
                        'mainDetail' => array('id' => 360, 'number' => 'SW10157',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    4 => array(
                        'id' => 158,
                        'name' => 'Strohhut mit UV Schutz',
                        'mainDetail' => array('id' => 361, 'number' => 'SW10158',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    5 => array(
                        'id' => 159,
                        'name' => 'Strohhut Women mit UV Schutz',
                        'mainDetail' => array('id' => 362, 'number' => 'SW10159',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    6 => array(
                        'id' => 166,
                        'name' => 'Sonnenbrille Big Eyes',
                        'mainDetail' => array('id' => 390, 'number' => 'SW10166',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    7 => array(
                        'id' => 167,
                        'name' => 'Sonnenbrille Speed Eyes',
                        'mainDetail' => array('id' => 391, 'number' => 'SW10167',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    8 => array(
                        'id' => 170,
                        'name' => 'Sonnenbrille "Red"',
                        'mainDetail' => array('id' => 394, 'number' => 'SW10170',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    9 => array(
                        'id' => 168,
                        'name' => 'Pilotenbrille Sunset Red',
                        'mainDetail' => array('id' => 392, 'number' => 'SW10168',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    10 => array(
                        'id' => 169,
                        'name' => 'Pilotenbrille Silver Sky',
                        'mainDetail' => array('id' => 393, 'number' => 'SW10169',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                ),
                'attribute' => array(
                    'id' => 41,
                    'categoryId' => 37,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        38 => array(
            0 => array(
                'id' => 38,
                'parentId' => 8,
                'name' => 'Dekoration',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Mit der richtigen Dekoration in eine Wohlfühlwelt',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 222,
                        'name' => 'Dekokissen Blume',
                        'mainDetail' => array('id' => 775, 'number' => 'SW10217',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    1 => array(
                        'id' => 224,
                        'name' => 'Dekokissen Bus',
                        'mainDetail' => array('id' => 777, 'number' => 'SW10218',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    2 => array(
                        'id' => 231,
                        'name' => 'Notizbuch New York',
                        'mainDetail' => array('id' => 786, 'number' => 'SW10223',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    3 => array(
                        'id' => 233,
                        'name' => 'Notizbuch London',
                        'mainDetail' => array('id' => 788, 'number' => 'SW10224',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    4 => array(
                        'id' => 234,
                        'name' => 'Notizbuch Paris',
                        'mainDetail' => array('id' => 789, 'number' => 'SW10225',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    5 => array(
                        'id' => 226,
                        'name' => 'Magnete ABC',
                        'mainDetail' => array('id' => 779, 'number' => 'SW10220',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    6 => array(
                        'id' => 94,
                        'name' => 'Blütenarrangement mit Rattan',
                        'mainDetail' => array('id' => 159, 'number' => 'SW10096',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    7 => array(
                        'id' => 95,
                        'name' => 'Blütenarrangement mit Rattan',
                        'mainDetail' => array('id' => 160, 'number' => 'SW10097',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    8 => array(
                        'id' => 93,
                        'name' => 'Blumenarrangement mit Keramiktopf',
                        'mainDetail' => array('id' => 158, 'number' => 'SW10095',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    9 => array(
                        'id' => 237,
                        'name' => 'Stoffherz kariert',
                        'mainDetail' => array('id' => 792, 'number' => 'SW10228',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    10 => array(
                        'id' => 236,
                        'name' => 'Servietten',
                        'mainDetail' => array('id' => 791, 'number' => 'SW10227',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    11 => array(
                        'id' => 235,
                        'name' => 'Deko Topf',
                        'mainDetail' => array('id' => 790, 'number' => 'SW10226',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    12 => array(
                        'id' => 229,
                        'name' => 'Magnete London',
                        'mainDetail' => array('id' => 784, 'number' => 'SW10222',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    13 => array(
                        'id' => 225,
                        'name' => 'Dekokissen Vogel',
                        'mainDetail' => array('id' => 778, 'number' => 'SW10219',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                ),
                'attribute' => array(
                    'id' => 42,
                    'categoryId' => 38,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        47 => array(
            0 => array(
                'id' => 47,
                'parentId' => 43,
                'name' => 'Teas and Accessories',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 35,
                        'name' => 'Schwarzer Tee Geschenkset',
                        'mainDetail' => array('id' => 41, 'number' => 'SW10034',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    1 => array(
                        'id' => 34,
                        'name' => 'Pu Erh Tee Geschenkset',
                        'mainDetail' => array('id' => 40, 'number' => 'SW10033',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    2 => array(
                        'id' => 33,
                        'name' => 'Oolong Tee Geschenkset',
                        'mainDetail' => array('id' => 39, 'number' => 'SW10032',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    3 => array(
                        'id' => 32,
                        'name' => 'Jasmine Tee Geschenk Set',
                        'mainDetail' => array('id' => 38, 'number' => 'SW10031',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    4 => array(
                        'id' => 31,
                        'name' => 'Grüner Tee Geschenkset',
                        'mainDetail' => array('id' => 37, 'number' => 'SW10030',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    5 => array(
                        'id' => 21,
                        'name' => 'Jasmine Lotus Tee',
                        'mainDetail' => array('id' => 27, 'number' => 'SW10020',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    6 => array(
                        'id' => 20,
                        'name' => 'Jasmine Phoenix Tee',
                        'mainDetail' => array('id' => 26, 'number' => 'SW10019',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    7 => array(
                        'id' => 18,
                        'name' => 'Pi Lo Chun grüner Tee',
                        'mainDetail' => array('id' => 24, 'number' => 'SW10017',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    8 => array(
                        'id' => 19,
                        'name' => 'Oriental Jasmine Tee',
                        'mainDetail' => array('id' => 25, 'number' => 'SW10018',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    9 => array(
                        'id' => 17,
                        'name' => 'Mao Feng grüner Tee',
                        'mainDetail' => array('id' => 23, 'number' => 'SW10016',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    10 => array(
                        'id' => 15,
                        'name' => 'LUNG CHING grüner Tee',
                        'mainDetail' => array('id' => 21, 'number' => 'SW10015',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    11 => array(
                        'id' => 14,
                        'name' => 'Silver Yin Zhen Tee weiss',
                        'mainDetail' => array('id' => 20, 'number' => 'SW10014',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    12 => array(
                        'id' => 13,
                        'name' => 'Pai Mu Tan Tee weiss',
                        'mainDetail' => array('id' => 19, 'number' => 'SW10013',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    13 => array(
                        'id' => 36,
                        'name' => 'Weißer Tee Geschenkset',
                        'mainDetail' => array('id' => 42, 'number' => 'SW10035',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    14 => array(
                        'id' => 22,
                        'name' => 'Glas -Teetasse 0,25l',
                        'mainDetail' => array('id' => 28, 'number' => 'SW10021',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    15 => array(
                        'id' => 23,
                        'name' => 'Glasbecher',
                        'mainDetail' => array('id' => 29, 'number' => 'SW10022',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    16 => array(
                        'id' => 24,
                        'name' => 'Glas-Teekännchen',
                        'mainDetail' => array('id' => 30, 'number' => 'SW10023',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    17 => array(
                        'id' => 25,
                        'name' => 'Glas-Teekanne',
                        'mainDetail' => array('id' => 31, 'number' => 'SW10024',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    18 => array(
                        'id' => 26,
                        'name' => 'Glas Teezubereiter',
                        'mainDetail' => array('id' => 32, 'number' => 'SW10025',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                ),
                'attribute' => array(
                    'id' => 51,
                    'categoryId' => 47,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        50 => array(
            0 => array(
                'id' => 50,
                'parentId' => 43,
                'name' => 'Brandies',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 122,
                        'name' => 'Sasse Korn 32%',
                        'mainDetail' => array('id' => 256, 'number' => 'SW10123.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    1 => array(
                        'id' => 11,
                        'name' => 'Münsterländer Aperitif Präsent Box',
                        'mainDetail' => array('id' => 17, 'number' => 'SW10011',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    2 => array(
                        'id' => 10,
                        'name' => 'Aperitif-Glas Demi Sec',
                        'mainDetail' => array('id' => 16, 'number' => 'SW10010',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    3 => array(
                        'id' => 9,
                        'name' => 'Special Finish Lagerkorn X.O. 32%',
                        'mainDetail' => array('id' => 15, 'number' => 'SW10009',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    4 => array(
                        'id' => 8,
                        'name' => 'T.S. Privat 41,5 %',
                        'mainDetail' => array('id' => 14, 'number' => 'SW10008',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    5 => array(
                        'id' => 6,
                        'name' => 'Cigar Special 40%',
                        'mainDetail' => array('id' => 6, 'number' => 'SW10006',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    6 => array(
                        'id' => 4,
                        'name' => 'Latte Macchiato 17%',
                        'mainDetail' => array('id' => 4, 'number' => 'SW10004',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    7 => array(
                        'id' => 3,
                        'name' => 'Münsterländer Aperitif 16%',
                        'mainDetail' => array('id' => 3, 'number' => 'SW10003',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    8 => array(
                        'id' => 5,
                        'name' => 'Emmelkamp Holunder Likör 18%',
                        'mainDetail' => array('id' => 252, 'number' => 'SW10005.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    9 => array(
                        'id' => 2,
                        'name' => 'Münsterländer Lagerkorn 32%',
                        'mainDetail' => array('id' => 125, 'number' => 'SW10002.3',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    10 => array(
                        'id' => 7,
                        'name' => 'Wacholder Premium extra mild 32%',
                        'mainDetail' => array('id' => 249, 'number' => 'SW10007.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    11 => array(
                        'id' => 12,
                        'name' => 'Kobra Vodka 37,5%',
                        'mainDetail' => array('id' => 18, 'number' => 'SW10012',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                ),
                'attribute' => array(
                    'id' => 54,
                    'categoryId' => 50,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        51 => array(
            0 => array(
                'id' => 51,
                'parentId' => 43,
                'name' => 'Delights',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 43,
                        'name' => 'Ölwechsel',
                        'mainDetail' => array('id' => 49, 'number' => 'SW10042',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    1 => array(
                        'id' => 41,
                        'name' => 'Traubenbatterie',
                        'mainDetail' => array('id' => 47, 'number' => 'SW10040',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    2 => array(
                        'id' => 40,
                        'name' => 'Schokoleim',
                        'mainDetail' => array('id' => 46, 'number' => 'SW10039',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    3 => array(
                        'id' => 39,
                        'name' => 'Mehrzwecknudeln',
                        'mainDetail' => array('id' => 45, 'number' => 'SW10038',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                    4 => array(
                        'id' => 44,
                        'name' => 'Bienenkleber',
                        'mainDetail' => array('id' => 50, 'number' => 'SW10043',),
                        'supplier' => array('id' => 4, 'name' => 'The Deli Garage',),
                    ),
                ),
                'attribute' => array(
                    'id' => 55,
                    'categoryId' => 51,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        52 => array(
            0 => array(
                'id' => 52,
                'parentId' => 44,
                'name' => 'Vintage',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 144,
                        'name' => 'Navigator Lederhaube schwarz',
                        'mainDetail' => array('id' => 291, 'number' => 'SW10144',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    1 => array(
                        'id' => 142,
                        'name' => 'Herrenhandschuh,halbfinger aus Peccary Leder',
                        'mainDetail' => array('id' => 289, 'number' => 'SW10142',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    2 => array(
                        'id' => 145,
                        'name' => 'Mütze Vintage Driver',
                        'mainDetail' => array('id' => 292, 'number' => 'SW10145',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    3 => array(
                        'id' => 143,
                        'name' => 'Navigator Lederhaube braun',
                        'mainDetail' => array('id' => 290, 'number' => 'SW10143',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                    4 => array(
                        'id' => 148,
                        'name' => 'Reisetasche Gladstone Wildleder',
                        'mainDetail' => array('id' => 295, 'number' => 'SW10148',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                ),
                'attribute' => array(
                    'id' => 56,
                    'categoryId' => 52,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        53 => array(
            0 => array(
                'id' => 53,
                'parentId' => 44,
                'name' => 'Entertainment',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 241,
                        'name' => 'Dartpfeil Steel Atomic',
                        'mainDetail' => array('id' => 796, 'number' => 'SW10232',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    1 => array(
                        'id' => 118,
                        'name' => 'Kicker Torzähler',
                        'mainDetail' => array('id' => 236, 'number' => 'SW10119',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    2 => array(
                        'id' => 116,
                        'name' => 'Kicker Champ, individuell gestaltbar',
                        'mainDetail' => array('id' => 186, 'number' => 'SW10117',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    3 => array(
                        'id' => 242,
                        'name' => 'Dartpfeil Steel Smiley 745',
                        'mainDetail' => array('id' => 797, 'number' => 'SW10233',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    4 => array(
                        'id' => 240,
                        'name' => 'Dartscheibe Circle',
                        'mainDetail' => array('id' => 795, 'number' => 'SW10231',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                    5 => array(
                        'id' => 239,
                        'name' => 'Dart Automat Standgerät',
                        'mainDetail' => array('id' => 794, 'number' => 'SW10230',),
                        'supplier' => array('id' => 9, 'name' => 'Heiku',),
                    ),
                ),
                'attribute' => array(
                    'id' => 57,
                    'categoryId' => 53,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        54 => array(
            0 => array(
                'id' => 54,
                'parentId' => 45,
                'name' => 'Furniture',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 77,
                        'name' => 'Couchtisch eckig weiß',
                        'mainDetail' => array('id' => 140, 'number' => 'SW10078',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    1 => array(
                        'id' => 74,
                        'name' => 'Stuhl',
                        'mainDetail' => array('id' => 137, 'number' => 'SW10075',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    2 => array(
                        'id' => 69,
                        'name' => 'Wandregal',
                        'mainDetail' => array('id' => 132, 'number' => 'SW10070',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    3 => array(
                        'id' => 64,
                        'name' => 'Briefkasten',
                        'mainDetail' => array('id' => 127, 'number' => 'SW10063',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    4 => array(
                        'id' => 67,
                        'name' => 'antike Kommode',
                        'mainDetail' => array('id' => 130, 'number' => 'SW10066',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    5 => array(
                        'id' => 248,
                        'name' => 'Versandkosten nach Gewicht',
                        'mainDetail' => array('id' => 803, 'number' => 'SW100755036993',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                ),
                'attribute' => array(
                    'id' => 58,
                    'categoryId' => 54,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        55 => array(
            0 => array(
                'id' => 55,
                'parentId' => 45,
                'name' => 'Kitchen Accessories',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 101,
                        'name' => 'Fliegenklatsche gelb',
                        'mainDetail' => array('id' => 166, 'number' => 'SW10100',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    1 => array(
                        'id' => 90,
                        'name' => 'Teller Style Hühner',
                        'mainDetail' => array('id' => 155, 'number' => 'SW10091',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    2 => array(
                        'id' => 83,
                        'name' => 'Back-Set 3 teilig',
                        'mainDetail' => array('id' => 146, 'number' => 'SW10084',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    3 => array(
                        'id' => 81,
                        'name' => 'Backform pink',
                        'mainDetail' => array('id' => 144, 'number' => 'SW10082',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    4 => array(
                        'id' => 78,
                        'name' => 'Uhr antik',
                        'mainDetail' => array('id' => 141, 'number' => 'SW10079',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                ),
                'attribute' => array(
                    'id' => 59,
                    'categoryId' => 55,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        56 => array(
            0 => array(
                'id' => 56,
                'parentId' => 45,
                'name' => 'Decoration',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 237,
                        'name' => 'Stoffherz kariert',
                        'mainDetail' => array('id' => 792, 'number' => 'SW10228',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    1 => array(
                        'id' => 236,
                        'name' => 'Servietten',
                        'mainDetail' => array('id' => 791, 'number' => 'SW10227',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    2 => array(
                        'id' => 235,
                        'name' => 'Deko Topf',
                        'mainDetail' => array('id' => 790, 'number' => 'SW10226',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    3 => array(
                        'id' => 229,
                        'name' => 'Magnete London',
                        'mainDetail' => array('id' => 784, 'number' => 'SW10222',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    4 => array(
                        'id' => 225,
                        'name' => 'Dekokissen Vogel',
                        'mainDetail' => array('id' => 778, 'number' => 'SW10219',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                ),
                'attribute' => array(
                    'id' => 60,
                    'categoryId' => 56,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        57 => array(
            0 => array(
                'id' => 57,
                'parentId' => 46,
                'name' => 'Beachwear',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 153,
                        'name' => 'Flip Flops, in mehreren Farben verfügbar',
                        'mainDetail' => array('id' => 322, 'number' => 'SW10153.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    1 => array(
                        'id' => 177,
                        'name' => 'Strandtuch Stripes für Kinder',
                        'mainDetail' => array('id' => 406, 'number' => 'SW10177',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    2 => array(
                        'id' => 160,
                        'name' => 'Sommer Sandale Ocean Blue',
                        'mainDetail' => array('id' => 364, 'number' => 'SW10160.1',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    3 => array(
                        'id' => 238,
                        'name' => 'Strandbag Sailor',
                        'mainDetail' => array('id' => 793, 'number' => 'SW10229',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    4 => array(
                        'id' => 213,
                        'name' => 'Surfbrett',
                        'mainDetail' => array('id' => 751, 'number' => 'SW10211',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                    5 => array(
                        'id' => 178,
                        'name' => 'Strandtuch "Ibiza"',
                        'mainDetail' => array('id' => 407, 'number' => 'SW10178',),
                        'supplier' => array('id' => 12, 'name' => 'Beachdreams Clothes',),
                    ),
                ),
                'attribute' => array(
                    'id' => 61,
                    'categoryId' => 57,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        58 => array(
            0 => array(
                'id' => 58,
                'parentId' => 46,
                'name' => 'Beauty & Care',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 131,
                        'name' => 'Sonnenschirm Sombrano, 350cm',
                        'mainDetail' => array('id' => 263, 'number' => 'SW10131',),
                        'supplier' => array('id' => 11, 'name' => 'Sonnenschirm Versand',),
                    ),
                    1 => array(
                        'id' => 129,
                        'name' => 'Sonnenschirm Fortino, 270cm',
                        'mainDetail' => array('id' => 261, 'number' => 'SW10129',),
                        'supplier' => array('id' => 11, 'name' => 'Sonnenschirm Versand',),
                    ),
                    2 => array(
                        'id' => 172,
                        'name' => 'Sonnencreme Sunblocker LSF 50',
                        'mainDetail' => array('id' => 401, 'number' => 'SW10172',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    3 => array(
                        'id' => 218,
                        'name' => 'All Natural - Lemon Honey Soap',
                        'mainDetail' => array('id' => 769, 'number' => 'SW10216.1',),
                        'supplier' => array('id' => 15, 'name' => 'stop the water while using me',),
                    ),
                ),
                'attribute' => array(
                    'id' => 62,
                    'categoryId' => 58,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        59 => array(
            0 => array(
                'id' => 59,
                'parentId' => 46,
                'name' => 'Travel around the World',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 181,
                        'name' => 'Reisekoffer Set',
                        'mainDetail' => array('id' => 421, 'number' => 'SW10181',),
                        'supplier' => array('id' => 5, 'name' => 'Access Oires Sisters',),
                    ),
                    1 => array(
                        'id' => 110,
                        'name' => 'Tasche Feed Me',
                        'mainDetail' => array('id' => 175, 'number' => 'SW10113',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    2 => array(
                        'id' => 104,
                        'name' => 'Reisekoffer klein',
                        'mainDetail' => array('id' => 169, 'number' => 'SW10105',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    3 => array(
                        'id' => 102,
                        'name' => 'iPadtasche mit Stiftmappe',
                        'mainDetail' => array('id' => 167, 'number' => 'SW10103',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    4 => array(
                        'id' => 148,
                        'name' => 'Reisetasche Gladstone Wildleder',
                        'mainDetail' => array('id' => 295, 'number' => 'SW10148',),
                        'supplier' => array('id' => 7, 'name' => 'Vintage Driver',),
                    ),
                ),
                'attribute' => array(
                    'id' => 63,
                    'categoryId' => 59,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        60 => array(
            0 => array(
                'id' => 60,
                'parentId' => 46,
                'name' => 'Accessories',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 170,
                        'name' => 'Sonnenbrille "Red"',
                        'mainDetail' => array('id' => 394, 'number' => 'SW10170',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    1 => array(
                        'id' => 166,
                        'name' => 'Sonnenbrille Big Eyes',
                        'mainDetail' => array('id' => 390, 'number' => 'SW10166',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    2 => array(
                        'id' => 159,
                        'name' => 'Strohhut Women mit UV Schutz',
                        'mainDetail' => array('id' => 362, 'number' => 'SW10159',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                    3 => array(
                        'id' => 157,
                        'name' => 'Panama Hut mit UV Schutz',
                        'mainDetail' => array('id' => 360, 'number' => 'SW10157',),
                        'supplier' => array('id' => 13, 'name' => 'Sun Smile and Protect',),
                    ),
                ),
                'attribute' => array(
                    'id' => 64,
                    'categoryId' => 60,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        62 => array(
            0 => array(
                'id' => 62,
                'parentId' => 61,
                'name' => 'Available soon',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(),
                'attribute' => array(
                    'id' => 66,
                    'categoryId' => 62,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        64 => array(
            0 => array(
                'id' => 64,
                'parentId' => 61,
                'name' => 'Customer loyalty',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 210,
                        'name' => 'Prämienartikel ab 50 Euro Warenkorb Wert',
                        'mainDetail' => array('id' => 748, 'number' => 'SW10209',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    1 => array(
                        'id' => 247,
                        'name' => 'Prämienartikel ab 100 Euro Warenkorbwert',
                        'mainDetail' => array('id' => 802, 'number' => 'SW10238',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    2 => array(
                        'id' => 211,
                        'name' => 'Prämienartikel ab 250 Euro Warenkorb Wert',
                        'mainDetail' => array('id' => 749, 'number' => 'SW10221',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                ),
                'attribute' => array(
                    'id' => 68,
                    'categoryId' => 64,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        65 => array(
            0 => array(
                'id' => 65,
                'parentId' => 61,
                'name' => 'Configurator articles',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 205,
                        'name' => 'Artikel mit Aufpreiskonfigurator',
                        'mainDetail' => array('id' => 726, 'number' => 'SW10204.1',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    1 => array(
                        'id' => 204,
                        'name' => 'Artikel mit Tabellenkonfigurator',
                        'mainDetail' => array('id' => 689, 'number' => 'SW10203.1',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    2 => array(
                        'id' => 203,
                        'name' => 'Artikel mit Auswahlkonfigurator',
                        'mainDetail' => array('id' => 549, 'number' => 'SW10202.1',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    3 => array(
                        'id' => 202,
                        'name' => 'Artikel mit Standardkonfigurator',
                        'mainDetail' => array('id' => 444, 'number' => 'SW10201.2',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                ),
                'attribute' => array(
                    'id' => 69,
                    'categoryId' => 65,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        67 => array(
            0 => array(
                'id' => 67,
                'parentId' => 61,
                'name' => 'Product comparison',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 122,
                        'name' => 'Sasse Korn 32%',
                        'mainDetail' => array('id' => 256, 'number' => 'SW10123.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    1 => array(
                        'id' => 4,
                        'name' => 'Latte Macchiato 17%',
                        'mainDetail' => array('id' => 4, 'number' => 'SW10004',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    2 => array(
                        'id' => 5,
                        'name' => 'Emmelkamp Holunder Likör 18%',
                        'mainDetail' => array('id' => 252, 'number' => 'SW10005.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    3 => array(
                        'id' => 2,
                        'name' => 'Münsterländer Lagerkorn 32%',
                        'mainDetail' => array('id' => 125, 'number' => 'SW10002.3',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    4 => array(
                        'id' => 7,
                        'name' => 'Wacholder Premium extra mild 32%',
                        'mainDetail' => array('id' => 249, 'number' => 'SW10007.1',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                    5 => array(
                        'id' => 12,
                        'name' => 'Kobra Vodka 37,5%',
                        'mainDetail' => array('id' => 18, 'number' => 'SW10012',),
                        'supplier' => array('id' => 2, 'name' => 'Feinbrennerei Sasse',),
                    ),
                ),
                'attribute' => array(
                    'id' => 71,
                    'categoryId' => 67,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        68 => array(
            0 => array(
                'id' => 68,
                'parentId' => 61,
                'name' => 'Presentation',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 243,
                        'name' => 'Artikel mit Emailbenachrichtigung',
                        'mainDetail' => array('id' => 798, 'number' => 'SW10234',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    1 => array(
                        'id' => 201,
                        'name' => 'Hervorgehobene Darstellung',
                        'mainDetail' => array('id' => 441, 'number' => 'SW10200',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    2 => array(
                        'id' => 200,
                        'name' => 'Artikelkennzeichnung NEU',
                        'mainDetail' => array('id' => 440, 'number' => 'SW10199',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    3 => array(
                        'id' => 199,
                        'name' => 'Artikel mit Abverkauf',
                        'mainDetail' => array('id' => 439, 'number' => 'SW10198',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    4 => array(
                        'id' => 198,
                        'name' => 'Artikel mit Bewertung',
                        'mainDetail' => array('id' => 438, 'number' => 'SW10197',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    5 => array(
                        'id' => 197,
                        'name' => 'ESD Download Artikel',
                        'mainDetail' => array('id' => 437, 'number' => 'SW10196',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                ),
                'attribute' => array(
                    'id' => 72,
                    'categoryId' => 68,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        69 => array(
            0 => array(
                'id' => 69,
                'parentId' => 61,
                'name' => 'Crossselling',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 194,
                        'name' => 'Artikel mit Zubehör',
                        'mainDetail' => array('id' => 434, 'number' => 'SW10193',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    1 => array(
                        'id' => 196,
                        'name' => 'Artikel mit ähnlichen Produkten',
                        'mainDetail' => array('id' => 436, 'number' => 'SW10195',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                ),
                'attribute' => array(
                    'id' => 73,
                    'categoryId' => 69,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        71 => array(
            0 => array(
                'id' => 71,
                'parentId' => 61,
                'name' => 'Payment methods',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 230,
                        'name' => 'Abschlag bei Zahlungsarten',
                        'mainDetail' => array('id' => 785, 'number' => 'SW10002694',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    1 => array(
                        'id' => 228,
                        'name' => 'Zahlungsarten & Riskmanagement',
                        'mainDetail' => array('id' => 783, 'number' => 'SW100025211',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    2 => array(
                        'id' => 227,
                        'name' => 'Aufschlag bei Zahlungsarten',
                        'mainDetail' => array('id' => 782, 'number' => 'SW10002841',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                ),
                'attribute' => array(
                    'id' => 75,
                    'categoryId' => 71,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        72 => array(
            0 => array(
                'id' => 72,
                'parentId' => 61,
                'name' => 'Shipping costs',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 221,
                        'name' => 'Versandkosten Optionen',
                        'mainDetail' => array('id' => 774, 'number' => 'SW1000299',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    1 => array(
                        'id' => 248,
                        'name' => 'Versandkosten nach Gewicht',
                        'mainDetail' => array('id' => 803, 'number' => 'SW100755036993',),
                        'supplier' => array('id' => 8, 'name' => 'Das blaue Haus',),
                    ),
                    2 => array(
                        'id' => 223,
                        'name' => 'Ausweichversandkosten',
                        'mainDetail' => array('id' => 780, 'number' => 'SW100718.1',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    3 => array(
                        'id' => 220,
                        'name' => 'Versandkostenfreier Artikel',
                        'mainDetail' => array('id' => 773, 'number' => 'SW10001',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    4 => array(
                        'id' => 219,
                        'name' => 'Express Versand',
                        'mainDetail' => array('id' => 772, 'number' => 'SW10185',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                ),
                'attribute' => array(
                    'id' => 76,
                    'categoryId' => 72,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        73 => array(
            0 => array(
                'id' => 73,
                'parentId' => 61,
                'name' => 'Price strategies',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 209,
                        'name' => 'Staffelpreise',
                        'mainDetail' => array('id' => 747, 'number' => 'SW10208',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    1 => array(
                        'id' => 206,
                        'name' => 'Artikel mit Grundpreisberechnung',
                        'mainDetail' => array('id' => 744, 'number' => 'SW10205.3',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    2 => array(
                        'id' => 208,
                        'name' => 'Pseudopreis',
                        'mainDetail' => array('id' => 746, 'number' => 'SW10207',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                    3 => array(
                        'id' => 207,
                        'name' => 'Staffelung, Mindest- / Maximalabnahme',
                        'mainDetail' => array('id' => 745, 'number' => 'SW10206',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                ),
                'attribute' => array(
                    'id' => 77,
                    'categoryId' => 73,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        74 => array(
            0 => array(
                'id' => 74,
                'parentId' => 10,
                'name' => 'Kundengruppen / B2B',
                'position' => 7,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Kundengruppen',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 244,
                        'name' => 'Kundengruppen Brutto / Nettopreise',
                        'mainDetail' => array('id' => 799, 'number' => 'SW10235',),
                        'supplier' => array('id' => 14, 'name' => 'Example',),
                    ),
                ),
                'attribute' => array(
                    'id' => 78,
                    'categoryId' => 74,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        75 => array(
            0 => array(
                'id' => 75,
                'parentId' => 10,
                'name' => 'Gutscheine',
                'position' => 1,
                                'metaKeywords' => null,
                'metaDescription' => null,
                'cmsHeadline' => null,
                'active' => false,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => null,
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => null,
                'articles' => array(),
                'attribute' => array(
                    'id' => 79,
                    'categoryId' => 75,
                    'attribute1' => null,
                    'attribute2' => null,
                    'attribute3' => null,
                    'attribute4' => null,
                    'attribute5' => null,
                    'attribute6' => null,
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        12 => array(
            0 => array(
                'id' => 12,
                'parentId' => 11,
                'name' => 'Tees',
                'position' => 0,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 21,
                        'name' => 'Jasmine Lotus Tee',
                        'mainDetail' => array('id' => 27, 'number' => 'SW10020',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    1 => array(
                        'id' => 13,
                        'name' => 'Pai Mu Tan Tee weiss',
                        'mainDetail' => array('id' => 19, 'number' => 'SW10013',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    2 => array(
                        'id' => 19,
                        'name' => 'Oriental Jasmine Tee',
                        'mainDetail' => array('id' => 25, 'number' => 'SW10018',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    3 => array(
                        'id' => 20,
                        'name' => 'Jasmine Phoenix Tee',
                        'mainDetail' => array('id' => 26, 'number' => 'SW10019',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    4 => array(
                        'id' => 18,
                        'name' => 'Pi Lo Chun grüner Tee',
                        'mainDetail' => array('id' => 24, 'number' => 'SW10017',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    5 => array(
                        'id' => 17,
                        'name' => 'Mao Feng grüner Tee',
                        'mainDetail' => array('id' => 23, 'number' => 'SW10016',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    6 => array(
                        'id' => 15,
                        'name' => 'LUNG CHING grüner Tee',
                        'mainDetail' => array('id' => 21, 'number' => 'SW10015',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    7 => array(
                        'id' => 14,
                        'name' => 'Silver Yin Zhen Tee weiss',
                        'mainDetail' => array('id' => 20, 'number' => 'SW10014',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    8 => array(
                        'id' => 31,
                        'name' => 'Grüner Tee Geschenkset',
                        'mainDetail' => array('id' => 37, 'number' => 'SW10030',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    9 => array(
                        'id' => 32,
                        'name' => 'Jasmine Tee Geschenk Set',
                        'mainDetail' => array('id' => 38, 'number' => 'SW10031',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    10 => array(
                        'id' => 33,
                        'name' => 'Oolong Tee Geschenkset',
                        'mainDetail' => array('id' => 39, 'number' => 'SW10032',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    11 => array(
                        'id' => 34,
                        'name' => 'Pu Erh Tee Geschenkset',
                        'mainDetail' => array('id' => 40, 'number' => 'SW10033',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    12 => array(
                        'id' => 35,
                        'name' => 'Schwarzer Tee Geschenkset',
                        'mainDetail' => array('id' => 41, 'number' => 'SW10034',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    13 => array(
                        'id' => 36,
                        'name' => 'Weißer Tee Geschenkset',
                        'mainDetail' => array('id' => 42, 'number' => 'SW10035',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                ),
                'attribute' => array(
                    'id' => 10,
                    'categoryId' => 12,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        13 => array(
            0 => array(
                'id' => 13,
                'parentId' => 11,
                'name' => 'Tee-Zubehör',
                'position' => 1,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tee-Zubehör',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 29,
                        'name' => 'Porzellan Teeservice',
                        'mainDetail' => array('id' => 35, 'number' => 'SW10028',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    1 => array(
                        'id' => 22,
                        'name' => 'Glas -Teetasse 0,25l',
                        'mainDetail' => array('id' => 28, 'number' => 'SW10021',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    2 => array(
                        'id' => 27,
                        'name' => 'Facil Teezubereiter',
                        'mainDetail' => array('id' => 33, 'number' => 'SW10026',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    3 => array(
                        'id' => 26,
                        'name' => 'Glas Teezubereiter',
                        'mainDetail' => array('id' => 32, 'number' => 'SW10025',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    4 => array(
                        'id' => 23,
                        'name' => 'Glasbecher',
                        'mainDetail' => array('id' => 29, 'number' => 'SW10022',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    5 => array(
                        'id' => 24,
                        'name' => 'Glas-Teekännchen',
                        'mainDetail' => array('id' => 30, 'number' => 'SW10023',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    6 => array(
                        'id' => 25,
                        'name' => 'Glas-Teekanne',
                        'mainDetail' => array('id' => 31, 'number' => 'SW10024',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    7 => array(
                        'id' => 28,
                        'name' => 'Deluxe Eisteezubereiter',
                        'mainDetail' => array('id' => 34, 'number' => 'SW10027',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    8 => array(
                        'id' => 30,
                        'name' => 'Porzellan Tee-Set in Geschenkbox',
                        'mainDetail' => array('id' => 36, 'number' => 'SW10029',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                ),
                'attribute' => array(
                    'id' => 11,
                    'categoryId' => 13,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        48 => array(
            0 => array(
                'id' => 48,
                'parentId' => 47,
                'name' => 'Teas',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 35,
                        'name' => 'Schwarzer Tee Geschenkset',
                        'mainDetail' => array('id' => 41, 'number' => 'SW10034',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    1 => array(
                        'id' => 34,
                        'name' => 'Pu Erh Tee Geschenkset',
                        'mainDetail' => array('id' => 40, 'number' => 'SW10033',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    2 => array(
                        'id' => 33,
                        'name' => 'Oolong Tee Geschenkset',
                        'mainDetail' => array('id' => 39, 'number' => 'SW10032',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    3 => array(
                        'id' => 32,
                        'name' => 'Jasmine Tee Geschenk Set',
                        'mainDetail' => array('id' => 38, 'number' => 'SW10031',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    4 => array(
                        'id' => 31,
                        'name' => 'Grüner Tee Geschenkset',
                        'mainDetail' => array('id' => 37, 'number' => 'SW10030',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    5 => array(
                        'id' => 21,
                        'name' => 'Jasmine Lotus Tee',
                        'mainDetail' => array('id' => 27, 'number' => 'SW10020',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    6 => array(
                        'id' => 20,
                        'name' => 'Jasmine Phoenix Tee',
                        'mainDetail' => array('id' => 26, 'number' => 'SW10019',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    7 => array(
                        'id' => 18,
                        'name' => 'Pi Lo Chun grüner Tee',
                        'mainDetail' => array('id' => 24, 'number' => 'SW10017',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    8 => array(
                        'id' => 19,
                        'name' => 'Oriental Jasmine Tee',
                        'mainDetail' => array('id' => 25, 'number' => 'SW10018',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    9 => array(
                        'id' => 17,
                        'name' => 'Mao Feng grüner Tee',
                        'mainDetail' => array('id' => 23, 'number' => 'SW10016',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    10 => array(
                        'id' => 15,
                        'name' => 'LUNG CHING grüner Tee',
                        'mainDetail' => array('id' => 21, 'number' => 'SW10015',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    11 => array(
                        'id' => 14,
                        'name' => 'Silver Yin Zhen Tee weiss',
                        'mainDetail' => array('id' => 20, 'number' => 'SW10014',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    12 => array(
                        'id' => 13,
                        'name' => 'Pai Mu Tan Tee weiss',
                        'mainDetail' => array('id' => 19, 'number' => 'SW10013',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    13 => array(
                        'id' => 36,
                        'name' => 'Weißer Tee Geschenkset',
                        'mainDetail' => array('id' => 42, 'number' => 'SW10035',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                ),
                'attribute' => array(
                    'id' => 52,
                    'categoryId' => 48,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
        49 => array(
            0 => array(
                'id' => 49,
                'parentId' => 47,
                'name' => 'Teas and accessories',
                'position' => null,
                                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'articles' => array(
                    0 => array(
                        'id' => 22,
                        'name' => 'Glas -Teetasse 0,25l',
                        'mainDetail' => array('id' => 28, 'number' => 'SW10021',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    1 => array(
                        'id' => 23,
                        'name' => 'Glasbecher',
                        'mainDetail' => array('id' => 29, 'number' => 'SW10022',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    2 => array(
                        'id' => 24,
                        'name' => 'Glas-Teekännchen',
                        'mainDetail' => array('id' => 30, 'number' => 'SW10023',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    3 => array(
                        'id' => 25,
                        'name' => 'Glas-Teekanne',
                        'mainDetail' => array('id' => 31, 'number' => 'SW10024',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                    4 => array(
                        'id' => 26,
                        'name' => 'Glas Teezubereiter',
                        'mainDetail' => array('id' => 32, 'number' => 'SW10025',),
                        'supplier' => array('id' => 3, 'name' => 'Teapavilion',),
                    ),
                ),
                'attribute' => array(
                    'id' => 53,
                    'categoryId' => 49,
                    'attribute1' => '',
                    'attribute2' => '',
                    'attribute3' => '',
                    'attribute4' => '',
                    'attribute5' => '',
                    'attribute6' => '',
                ),
                'emotions' => array(),
                'media' => null,
                'customerGroups' => array(),
            ),
        ),
    );

    /**
     * @return Shopware\Models\Category\Repository
     */
    protected function getRepo()
    {
        if ($this->repo === null) {
            $this->repo = Shopware()->Models()->Category();
        }
        return $this->repo;
    }

    public function testQuery()
    {
        foreach ($this->expected as $id => $expected) {
            $query = $this->getRepo()->getDetailQuery($id);
            $data = $this->removeDates($query->getArrayResult());
            $this->assertEquals($expected, $data);
        }
    }

    /**
     * Test if the query returns all necessary information
     *
     * @ticket SW-5474
     */
    public function testCategoryBackendGetDetailQuery()
    {
        /** @var $repository Shopware\Models\Category\Repository */
        $repository = Shopware()->Models()->getRepository('Shopware\Models\Category\Category');

        //category Edelbrände
        $categoryDetailArray = $repository->getDetailQuery(14)->getArrayResult();

        $articleData = $categoryDetailArray[0]["articles"][0];
        $this->assertNotEmpty($articleData);

        $this->assertEquals(10, $articleData["id"]);
        $this->assertEquals('Aperitif-Glas Demi Sec', $articleData["name"]);

        $mainDetailData = $articleData["mainDetail"];
        $this->assertNotEmpty($mainDetailData);
        $this->assertEquals('16', $mainDetailData["id"]);
        $this->assertEquals('SW10010', $mainDetailData["number"]);

        $supplierData = $articleData["supplier"];
        $this->assertNotEmpty($supplierData);
        $this->assertEquals('2', $supplierData["id"]);
        $this->assertEquals('Feinbrennerei Sasse', $supplierData["name"]);
    }

    protected function removeDates($data)
    {
        foreach ($data as &$subCategory) {
            unset($subCategory['changed']);
            unset($subCategory['descriptionLong']);
            unset($subCategory['cmsText']);
            unset($subCategory['added']);
            foreach ($subCategory['emotions'] as &$emotion) {
                unset($emotion['createDate']);
                unset($emotion['modified']);
            }
            foreach ($subCategory['articles'] as &$article) {
                unset($article['added']);
                unset($article['changed']);
                unset($article['descriptionLong']);
                unset($article['description']);
                unset($article['mainDetail']['releaseDate']);
            }
        }
        return $data;
    }
}
